<?php
/* Copyright (C) 2003-2004	Rodolphe Quiedeville		<rodolphe@quiedeville.org>
 * Copyright (C) 2004-2019	Laurent Destailleur			<eldy@users.sourceforge.net>
 * Copyright (C) 2005-2014	Regis Houssin				<regis.houssin@inodbox.com>
 * Copyright (C) 2006		Andre Cianfarani			<acianfa@free.fr>
 * Copyright (C) 2010-2017	Juanjo Menent				<jmenent@2byte.es>
 * Copyright (C) 2013		Christophe Battarel			<christophe.battarel@altairis.fr>
 * Copyright (C) 2013-2014	Florian Henry				<florian.henry@open-concept.pro>
 * Copyright (C) 2014-2020	Ferran Marcet				<fmarcet@2byte.es>
 * Copyright (C) 2014-2016	Marcos García				<marcosgdf@gmail.com>
 * Copyright (C) 2015		Jean-François Ferry			<jfefe@aternatik.fr>
 * Copyright (C) 2018-2024	Frédéric France				<frederic.france@free.fr>
 * Copyright (C) 2023		Charlene Benke				<charlene@patas-monkey.com>
 * Copyright (C) 2023		Nick Fragoulis
 * Copyright (C) 2024		MDW							<mdeweerd@users.noreply.github.com>
 * Copyright (C) 2024		Alexandre Spangaro			<alexandre@inovea-conseil.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *       \file       htdocs/suppliercontract/card.php
 *       \ingroup    suppliercontract
 *       \brief      Page of a supplier contract
 */

//require "../main.inc.php";
// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
	$res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"]."/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME'];
$tmp2 = realpath(__FILE__);
$i = strlen($tmp) - 1;
$j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
	$i--;
	$j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1))."/main.inc.php")) {
	$res = @include substr($tmp, 0, ($i + 1))."/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php")) {
	$res = @include dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) {
	$res = @include "../main.inc.php";
}
if (!$res && file_exists("../../main.inc.php")) {
	$res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
	$res = @include "../../../main.inc.php";
}
if (!$res) {
	die("Include of main fails");
}
require_once DOL_DOCUMENT_ROOT.'/core/lib/date.lib.php';
require_once DOL_DOCUMENT_ROOT.'/core/lib/price.lib.php';
//require_once DOL_DOCUMENT_ROOT.'/core/lib/suppliercontract.lib.php';
//require_once DOL_DOCUMENT_ROOT.'/suppliercontract/class/suppliercontract.class.php';
//require_once DOL_DOCUMENT_ROOT.'/core/modules/suppliercontract/modules_suppliercontract.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT.'/product/class/product.class.php';
require_once DOL_DOCUMENT_ROOT.'/compta/facture/class/facture.class.php';
require_once DOL_DOCUMENT_ROOT.'/fourn/class/fournisseur.facture.class.php';
if (isModEnabled("propal")) {
	require_once DOL_DOCUMENT_ROOT.'/comm/propal/class/propal.class.php';
}
if (isModEnabled('project')) {
	require_once DOL_DOCUMENT_ROOT.'/projet/class/project.class.php';
	require_once DOL_DOCUMENT_ROOT.'/core/class/html.formprojet.class.php';
}
require_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';
dol_include_once('/suppliercontract/core/lib/suppliercontract.lib.php');
dol_include_once('/suppliercontract/class/suppliercontract.class.php');
dol_include_once('/suppliercontract/core/modules/suppliercontract/modules_suppliercontract.php');

// Load translation files required by the page
$langs->loadLangs(array("contracts", "orders", "companies", "bills", "products", 'compta', 'propal', 'suppliercontracts@suppliercontract'));

$action = GETPOST('action', 'aZ09');
$confirm = GETPOST('confirm', 'alpha');
$cancel = GETPOST('cancel', 'alpha');
$backtopage = GETPOST('backtopage', 'alpha');

$socid = GETPOSTINT('socid');
$id = GETPOSTINT('id');
$ref = GETPOST('ref', 'alpha');
$origin = GETPOST('origin', 'alpha');
$originid = GETPOSTINT('originid');
$idline = GETPOSTINT('elrowid') ? GETPOSTINT('elrowid') : GETPOSTINT('rowid');
$rank = (GETPOSTINT('rank') > 0) ? GETPOSTINT('rank') : -1;

// PDF
$hidedetails = (GETPOSTINT('hidedetails') ? GETPOSTINT('hidedetails') : (getDolGlobalString('MAIN_GENERATE_DOCUMENTS_HIDE_DETAILS') ? 1 : 0));
$hidedesc = (GETPOSTINT('hidedesc') ? GETPOSTINT('hidedesc') : (getDolGlobalString('MAIN_GENERATE_DOCUMENTS_HIDE_DESC') ? 1 : 0));
$hideref = (GETPOSTINT('hideref') ? GETPOSTINT('hideref') : (getDolGlobalString('MAIN_GENERATE_DOCUMENTS_HIDE_REF') ? 1 : 0));


$datecontract = '';
$moreparam = '';
$note_public = '';
$note_private = '';
$usehm = (getDolGlobalString('MAIN_USE_HOURMIN_IN_DATE_RANGE') ? $conf->global->MAIN_USE_HOURMIN_IN_DATE_RANGE : 0);

// Security check
if ($user->socid) {
	$socid = $user->socid;
}

// Initialize a technical object to manage hooks of page. Note that conf->hooks_modules contains an array of hook context
$hookmanager->initHooks(array('suppliercontractcard', 'globalcard'));

$object = new SupplierContract($db);
$extrafields = new ExtraFields($db);
$ret = 0;
$pu_ht = null;  // Init for static analysis
$pu_ttc = null;  // Init for static analysis

// Load object
if ($id > 0 || !empty($ref) && $action != 'add') {
	$ret = $object->fetch($id, $ref);
	if ($ret > 0) {
		$ret = $object->fetch_thirdparty();
	}
	if ($ret < 0) {
		dol_print_error(null, $object->errorsToString());
	}
}

// fetch optionals attributes and labels
$extrafields->fetch_name_optionals_label($object->table_element);

// fetch optionals attributes lines and labels
$extralabelslines = $extrafields->fetch_name_optionals_label($object->table_element_line);

$permissionnote = $user->hasRight('suppliercontract', 'creer'); // Used by the include of actions_setnotes.inc.php
$permissiondellink = $user->hasRight('suppliercontract', 'creer'); // Used by the include of actions_dellink.inc.php
$permissiontodelete = ($user->hasRight('suppliercontract', 'creer') && $object->status == $object::STATUS_DRAFT) || $user->hasRight('suppliercontract', 'supprimer');
$permissiontoadd   = $user->hasRight('suppliercontract', 'creer');     //  Used by the include of actions_addupdatedelete.inc.php and actions_lineupdown.inc.php
$permissiontoedit = $permissiontoadd;
$permissiontoactivate = $user->hasRight('suppliercontract', 'activer');
$error = 0;

$result = restrictedArea($user, 'suppliercontract', $object->id);


/*
 * Actions
 */

$parameters = array('socid' => $socid);
$reshook = $hookmanager->executeHooks('doActions', $parameters, $object, $action); // Note that $action and $object may have been modified by some hooks
if ($reshook < 0) {
	setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
}
if (empty($reshook)) {
	$backurlforlist = dol_buildpath('/suppliercontract/list.php', 1);

	if (empty($backtopage) || ($cancel && empty($id))) {
		if (empty($backtopage) || ($cancel && strpos($backtopage, '__ID__'))) {
			if (empty($id) && (($action != 'add' && $action != 'create') || $cancel)) {
				$backtopage = $backurlforlist;
			} else {
				$backtopage = dol_buildpath('/suppliercontract/card.php',1).'?id='.((!empty($id) && $id > 0) ? $id : '__ID__');
			}
		}
	}

	if ($cancel) {
		if (!empty($backtopageforcancel)) {
			header("Location: ".$backtopageforcancel);
			exit;
		} elseif (!empty($backtopage)) {
			header("Location: ".$backtopage);
			exit;
		}
		$action = '';
	}

	include DOL_DOCUMENT_ROOT.'/core/actions_setnotes.inc.php'; // Must be include, not includ_once

	include DOL_DOCUMENT_ROOT.'/core/actions_dellink.inc.php'; // Must be 'include', not 'include_once'

	include DOL_DOCUMENT_ROOT.'/core/actions_lineupdown.inc.php';  // Must be 'include', not 'include_once'

	if ($action == 'confirm_active' && $confirm == 'yes' && $permissiontoactivate) {
		$date_start = '';
		$date_end = '';
		if (GETPOST('startmonth') && GETPOST('startday') && GETPOST('startyear')) {
			$date_start = dol_mktime(GETPOST('starthour'), GETPOST('startmin'), 0, GETPOST('startmonth'), GETPOST('startday'), GETPOST('startyear'));
		}
		if (GETPOST('endmonth') && GETPOST('endday') && GETPOST('endyear')) {
			$date_end = dol_mktime(GETPOST('endhour'), GETPOST('endmin'), 0, GETPOST('endmonth'), GETPOST('endday'), GETPOST('endyear'));
		}

		$result = $object->active_line($user, GETPOSTINT('ligne'), $date_start, $date_end, GETPOST('comment'));

		if ($result > 0) {
			header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
			exit;
		} else {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'confirm_sign' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		$result = $object->setSignedStatus($user, GETPOSTINT('signed_status'), 0, 'SUPPLIERCONTRACT_MODIFY');
		if ($result >= 0) {
			header('Location: ' . $_SERVER["PHP_SELF"] . '?id=' . $object->id);
			exit;
		} else {
			$mesg = $object->error;
		}
	} elseif ($action == 'confirm_unsign' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		$result = $object->setSignedStatus($user, SupplierContract::$SIGNED_STATUSES['STATUS_NO_SIGNATURE'], 0, 'SUPPLIERCONTRACT_MODIFY');
		if ($result >= 0) {
			header('Location: ' . $_SERVER["PHP_SELF"] . '?id=' . $object->id);
			exit;
		} else {
			$mesg = $object->error;
		}
	} elseif ($action == 'confirm_closeline' && $confirm == 'yes' && $permissiontoactivate) {
		$date_end = '';
		if (GETPOST('endmonth') && GETPOST('endday') && GETPOST('endyear')) {
			$date_end = dol_mktime(GETPOST('endhour'), GETPOST('endmin'), 0, GETPOST('endmonth'), GETPOST('endday'), GETPOST('endyear'));
		}
		if (!$date_end) {
			$error++;
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("DateEnd")), null, 'errors');
		}
		if (!$error) {
			$result = $object->close_line($user, GETPOSTINT('ligne'), $date_end, urldecode(GETPOST('comment')));
			if ($result > 0) {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			} else {
				setEventMessages($object->error, $object->errors, 'errors');
			}
		}
	}

	if (GETPOST('mode') == 'predefined') {
		$date_start = '';
		$date_end = '';
		if (GETPOST('date_startmonth') && GETPOST('date_startday') && GETPOST('date_startyear')) {
			$date_start = dol_mktime(GETPOST('date_starthour'), GETPOST('date_startmin'), 0, GETPOST('date_startmonth'), GETPOST('date_startday'), GETPOST('date_startyear'));
		}
		if (GETPOST('date_endmonth') && GETPOST('date_endday') && GETPOST('date_endyear')) {
			$date_end = dol_mktime(GETPOST('date_endhour'), GETPOST('date_endmin'), 0, GETPOST('date_endmonth'), GETPOST('date_endday'), GETPOST('date_endyear'));
		}
	}

	// Param dates
	$date_start_update = '';
	$date_end_update = '';
	$date_start_real_update = '';
	$date_end_real_update = '';
	if (GETPOST('date_start_updatemonth') && GETPOST('date_start_updateday') && GETPOST('date_start_updateyear')) {
		$date_start_update = dol_mktime(GETPOST('date_start_updatehour'), GETPOST('date_start_updatemin'), 0, GETPOST('date_start_updatemonth'), GETPOST('date_start_updateday'), GETPOST('date_start_updateyear'));
	}
	if (GETPOST('date_end_updatemonth') && GETPOST('date_end_updateday') && GETPOST('date_end_updateyear')) {
		$date_end_update = dol_mktime(GETPOST('date_end_updatehour'), GETPOST('date_end_updatemin'), 0, GETPOST('date_end_updatemonth'), GETPOST('date_end_updateday'), GETPOST('date_end_updateyear'));
	}
	if (GETPOST('date_start_real_updatemonth') && GETPOST('date_start_real_updateday') && GETPOST('date_start_real_updateyear')) {
		$date_start_real_update = dol_mktime(GETPOST('date_start_real_updatehour'), GETPOST('date_start_real_updatemin'), 0, GETPOST('date_start_real_updatemonth'), GETPOST('date_start_real_updateday'), GETPOST('date_start_real_updateyear'));
	}
	if (GETPOST('date_end_real_updatemonth') && GETPOST('date_end_real_updateday') && GETPOST('date_end_real_updateyear')) {
		$date_end_real_update = dol_mktime(GETPOST('date_end_real_updatehour'), GETPOST('date_end_real_updatemin'), 0, GETPOST('date_end_real_updatemonth'), GETPOST('date_end_real_updateday'), GETPOST('date_end_real_updateyear'));
	}
	if (GETPOST('remonth') && GETPOST('reday') && GETPOST('reyear')) {
		$datecontract = dol_mktime(GETPOST('rehour'), GETPOST('remin'), 0, GETPOST('remonth'), GETPOST('reday'), GETPOST('reyear'));
	}

	// Add supplier contract
	if ($action == 'add' && $user->hasRight('suppliercontract', 'creer')) {
		$commercial_suivi_id = GETPOSTINT('commercial_suivi_id');
		$commercial_signature_id = GETPOSTINT('commercial_signature_id');

		// Check
		if (empty($datecontract)) {
			$error++;
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("Date")), null, 'errors');
			$action = 'create';
		}

		if ($socid < 1) {
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("ThirdParty")), null, 'errors');
			$action = 'create';
			$error++;
		}
		if ($commercial_suivi_id <= 0) {
			$langs->load("commercial");
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("SalesRepresentativeSignature")), null, 'errors');
			$action = 'create';
			$error++;
		}
		if ($commercial_signature_id <= 0) {
			$langs->load("commercial");
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("SalesRepresentativeFollowUp")), null, 'errors');
			$action = 'create';
			$error++;
		}

		// Fill array 'array_options' with data from add form
		$ret = $extrafields->setOptionalsFromPost(null, $object);
		if ($ret < 0) {
			$error++;
			$action = 'create';
		}

		if (!$error) {
			$object->socid = $socid;
			$object->date_contract = $datecontract;

			$object->note_private = GETPOST('note_private', 'alpha');
			$object->note_public				= GETPOST('note_public', 'alpha');
			$object->fk_project					= GETPOSTINT('projectid');
			$object->remise_percent = price2num(GETPOST('remise_percent'), '', 2);
			$object->ref = GETPOST('ref', 'alpha');
			$object->ref_customer				= GETPOST('ref_customer', 'alpha');
			$object->ref_supplier				= GETPOST('ref_supplier', 'alpha');

			// If creation from another object of another module (Example: origin=propal, originid=1)
			if (!empty($origin) && !empty($originid)) {
				$object->origin    = $origin;
				$object->origin_id = $originid;

				// Possibility to add external linked objects with hooks
				$object->linked_objects[$object->origin] = $object->origin_id;
				if (GETPOSTISARRAY('other_linked_objects')) {
					$object->linked_objects = array_merge($object->linked_objects, GETPOST('other_linked_objects', 'array:int'));
				}

				$id = $object->create($user);
				if ($id > 0) {
					dol_syslog("Try to find source object origin=".$object->origin." originid=".$object->origin_id." to add lines");
					$srcobject = fetchObjectByElement($object->origin_id, $object->origin);
					'@phan-var-force CommandeFournisseur|SupplierProposal|FactureFournisseur $srcobject';

					if (is_object($srcobject) && $srcobject->id > 0) {
						$srcobject->fetch_thirdparty();
						$lines = $srcobject->lines;
						if (empty($lines) && method_exists($srcobject, 'fetch_lines')) {
							$srcobject->fetch_lines();
							$lines = $srcobject->lines;
						}

						$fk_parent_line = 0;
						$num = count($lines);

						for ($i = 0; $i < $num; $i++) {
							$product_type = ($lines[$i]->product_type ? $lines[$i]->product_type : 0);

							if ($product_type == 1 || (getDolGlobalString('SUPPLIERCONTRACT_SUPPORT_PRODUCTS') && in_array($product_type, array(0, 1)))) { 	// TODO Exclude also deee
								// service prédéfini
								if ($lines[$i]->fk_product > 0) {
									$product_static = new Product($db);

									// Define output language
									if (getDolGlobalInt('MAIN_MULTILANGS') && getDolGlobalString('PRODUIT_TEXTS_IN_THIRDPARTY_LANGUAGE')) {
										$prod = new Product($db);
										$prod->id = $lines[$i]->fk_product;
										$prod->getMultiLangs();

										$outputlangs = $langs;
										$newlang = '';
										if (empty($newlang) && GETPOST('lang_id', 'aZ09')) {
											$newlang = GETPOST('lang_id', 'aZ09');
										}
										if (empty($newlang)) {
											$newlang = $srcobject->thirdparty->default_lang;
										}
										if (!empty($newlang)) {
											$outputlangs = new Translate("", $conf);
											$outputlangs->setDefaultLang($newlang);
										}

										$label = (!empty($prod->multilangs[$outputlangs->defaultlang]["libelle"])) ? $prod->multilangs[$outputlangs->defaultlang]["libelle"] : $lines[$i]->product_label;
									} else {
										$label = $lines[$i]->product_label;
									}
									$desc = ($lines[$i]->desc && $lines[$i]->desc != $lines[$i]->label) ? dol_htmlentitiesbr($lines[$i]->desc) : '';
								} else {
									$desc = dol_htmlentitiesbr($lines[$i]->desc);
								}

								// Extrafields
								$array_options = array();
								// For avoid conflicts if trigger used
								if (method_exists($lines[$i], 'fetch_optionals')) {
									$lines[$i]->fetch_optionals();
									$array_options = $lines[$i]->array_options;
								}

								$txtva = $lines[$i]->vat_src_code ? $lines[$i]->tva_tx.' ('.$lines[$i]->vat_src_code.')' : $lines[$i]->tva_tx;

								// View third's localtaxes for now
								$localtax1_tx = get_localtax($txtva, 1, $object->thirdparty);
								$localtax2_tx = get_localtax($txtva, 2, $object->thirdparty);

								$result = $object->addline(
									$desc,
									$lines[$i]->subprice,
									$lines[$i]->qty,
									$txtva,
									$localtax1_tx,
									$localtax2_tx,
									$lines[$i]->fk_product,
									$lines[$i]->remise_percent,
									$lines[$i]->date_start,
									$lines[$i]->date_end,
									'HT',
									0,
									$lines[$i]->info_bits,
									$lines[$i]->fk_fournprice,
									$lines[$i]->pa_ht,
									$array_options,
									$lines[$i]->fk_unit,
									$num + 1
								);

								if ($result < 0) {
									$error++;
									break;
								}
							}
						}
					} else {
						setEventMessages($srcobject->error, $srcobject->errors, 'errors');
						$error++;
					}
					if (!$error) {
						// Insert business contacts ('SALESREPSIGN','suppliercontract')
						$result = $object->add_contact($commercial_signature_id, 'SALESREPSIGN', 'internal');
						if ($result < 0) {
							setEventMessages($object->error, $object->errors, 'errors');
							$error++;
						}
					}
					if (!$error) {
						// Insert business contacts ('SALESREPFOLL','suppliercontract')
						$result = $object->add_contact($commercial_suivi_id, 'SALESREPFOLL', 'internal');
						if ($result < 0) {
							setEventMessages($object->error, $object->errors, 'errors');
							$error++;
						}
					}

					// Hooks
					$parameters = array('objFrom' => $srcobject);
					$reshook = $hookmanager->executeHooks('createFrom', $parameters, $object, $action); // Note that $action and $object may have been
					// modified by hook
					if ($reshook < 0) {
						setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
						$error++;
					}
				} else {
					setEventMessages($object->error, $object->errors, 'errors');
					$error++;
				}
				if ($error) {
					$action = 'create';
				}
			} else {
				$result = $object->create($user);
				if ($result > 0) {
					// Insert business contacts ('SALESREPSIGN','suppliercontract')
					$result = $object->add_contact($commercial_signature_id, 'SALESREPSIGN', 'internal');
				}
				if ($result > 0) {
					// Insert business contacts ('SALESREPFOLL','suppliercontract')
					$result = $object->add_contact($commercial_suivi_id, 'SALESREPFOLL', 'internal');
				}
				if ($result > 0) {
					header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
					exit;
				} else {
					setEventMessages($object->error, $object->errors, 'errors');
				}
				$action = 'create';
			}
		}
	} elseif ($action == 'classin' && $user->hasRight('suppliercontract', 'creer')) {
		$object->setProject(GETPOST('projectid'));
	} elseif ($action == 'addline' && $user->hasRight('suppliercontract', 'creer')) {
		$langs->load('errors');
		$error = 0;

		// Set if we used free entry or predefined product
		$predef = '';
		$product_desc = (GETPOSTISSET('dp_desc') ? GETPOST('dp_desc', 'restricthtml') : '');
		$date_start = dol_mktime(GETPOST('date_start' . $predef . 'hour'), GETPOST('date_start' . $predef . 'min'), GETPOST('date_start' . $predef . 'sec'), GETPOST('date_start' . $predef . 'month'), GETPOST('date_start' . $predef . 'day'), GETPOST('date_start' . $predef . 'year'));
		$date_end = dol_mktime(GETPOST('date_end' . $predef . 'hour'), GETPOST('date_end' . $predef . 'min'), GETPOST('date_end' . $predef . 'sec'), GETPOST('date_end' . $predef . 'month'), GETPOST('date_end' . $predef . 'day'), GETPOST('date_end' . $predef . 'year'));
		if (!empty($date_start) && !empty($date_end) && $date_start > $date_end) {
			setEventMessages($langs->trans("Error").': '.$langs->trans("DateStartPlanned").' > '.$langs->trans("DateEndPlanned"), null, 'errors');
			$error++;
		}

		$ref_supplier = GETPOST('fourn_ref', 'alpha');

		$prod_entry_mode = GETPOST('prod_entry_mode', 'aZ09');
		if ($prod_entry_mode == 'free') {
			$idprod = 0;
		} else {
			$idprod = GETPOSTINT('idprod');
		}

		if (getDolGlobalString('MAIN_DISABLE_FREE_LINES') && $idprod <= 0) {
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("ProductOrService")), null, 'errors');
			$error++;
		}

		$tva_tx = (GETPOST('tva_tx') ? GETPOST('tva_tx') : 0);        // Can be '1.2' or '1.2 (CODE)'

		$price_ht = price2num(GETPOST('price_ht'), 'MU', 2);
		$price_ht_devise = price2num(GETPOST('multicurrency_price_ht'), 'CU', 2);
		$price_ttc = price2num(GETPOST('price_ttc'), 'MU', 2);
		$price_ttc_devise = price2num(GETPOST('multicurrency_price_ttc'), 'CU', 2);

		$qty = price2num(GETPOST('qty' . $predef, 'alpha'), 'MS', 2);

		$remise_percent = (GETPOSTISSET('remise_percent' . $predef) ? price2num(GETPOST('remise_percent' . $predef, 'alpha'), '', 2) : 0);
		if (empty($remise_percent)) {
			$remise_percent = 0;
		}

		// Extrafields
		$extralabelsline = $extrafields->fetch_name_optionals_label($object->table_element_line);
		$array_options = $extrafields->getOptionalsFromPost($object->table_element_line, $predef);
		// Unset extrafield
		if (is_array($extralabelsline)) {
			// Get extra fields
			foreach ($extralabelsline as $key => $value) {
				unset($_POST["options_" . $key]);
			}
		}

		if ($prod_entry_mode == 'free' && GETPOST('price_ht') < 0 && $qty < 0) {
			setEventMessages($langs->trans('ErrorBothFieldCantBeNegative', $langs->transnoentitiesnoconv('UnitPrice'), $langs->transnoentitiesnoconv('Qty')), null, 'errors');
			$error++;
		}
		if ($prod_entry_mode == 'free' && (empty($idprod) || $idprod < 0) && GETPOST('type') < 0) {
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("Type")), null, 'errors');
			$error++;
		}

		if ($prod_entry_mode == 'free' && (empty($idprod) || $idprod < 0) && GETPOST('price_ht') === '' && GETPOST('price_ttc') === '' && GETPOST('multicurrency_price_ht') === '') {    // Unit price can be 0 but not ''. Also price can be negative for proposal.
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("UnitPrice")), null, 'errors');
			$error++;
		}
		if ($prod_entry_mode == 'free' && (empty($idprod) || $idprod < 0) && empty($product_desc)) {
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("Description")), null, 'errors');
			$error++;
		}
		if (!$error && ($qty >= 0)) {
			$pu_ht = price2num($price_ht, 'MU');
			$pu_ttc = price2num(GETPOST('price_ttc'), 'MU');
			$price_min = 0;
			$price_base_type = (GETPOST('price_base_type', 'alpha') ? GETPOST('price_base_type', 'alpha') : 'HT');

			$db->begin();

			if ($prod_entry_mode != 'free' && empty($error)) {    // With combolist mode idprodfournprice is > 0 or -1. With autocomplete, idprodfournprice is > 0 or ''
				$productsupplier = new ProductFournisseur($db);

				$idprod = 0;
				if (GETPOST('idprodfournprice', 'alpha') == -1 || GETPOST('idprodfournprice', 'alpha') == '') {
					$idprod = -99; // Same behaviour than with combolist. When not select idprodfournprice is now -99 (to avoid conflict with next action that may return -1, -2, ...)
				}

				$reg = array();
				if (preg_match('/^idprod_([0-9]+)$/', GETPOST('idprodfournprice', 'alpha'), $reg)) {
					$idprod = $reg[1];
					$res = $productsupplier->fetch($idprod); // Load product from its id
					// Call to init some price properties of $productsupplier
					// So if a supplier price already exists for another thirdparty (first one found), we use it as reference price
					if (getDolGlobalString('SUPPLIER_TAKE_FIRST_PRICE_IF_NO_PRICE_FOR_CURRENT_SUPPLIER')) {
						$fksoctosearch = 0;
						$productsupplier->get_buyprice(0, -1, $idprod, 'none', $fksoctosearch); // We force qty to -1 to be sure to find if a supplier price exist
						if ($productsupplier->fourn_socid != $socid) {    // The price we found is for another supplier, so we clear supplier price
							$productsupplier->ref_supplier = '';
						}
					} else {
						$fksoctosearch = $object->thirdparty->id;
						$productsupplier->get_buyprice(0, -1, $idprod, 'none', $fksoctosearch); // We force qty to -1 to be sure to find if a supplier price exist
					}
				} elseif (GETPOST('idprodfournprice', 'alpha') > 0) {
					//$qtytosearch=$qty; 	   // Just to see if a price exists for the quantity. Not used to found vat.
					$qtytosearch = -1; // We force qty to -1 to be sure to find if the supplier price that exists
					$idprod = $productsupplier->get_buyprice(GETPOST('idprodfournprice', 'alpha'), $qtytosearch);
					$res = $productsupplier->fetch($idprod);
				}

				if ($idprod > 0) {
					$label = $productsupplier->label;

					// Define output language
					if (getDolGlobalInt('MAIN_MULTILANGS') && getDolGlobalString('PRODUIT_TEXTS_IN_THIRDPARTY_LANGUAGE')) {
						$outputlangs = $langs;
						$newlang = '';
						if (empty($newlang) && GETPOST('lang_id', 'aZ09')) {
							$newlang = GETPOST('lang_id', 'aZ09');
						}
						if (empty($newlang)) {
							$newlang = $object->thirdparty->default_lang;
						}
						if (!empty($newlang)) {
							$outputlangs = new Translate("", $conf);
							$outputlangs->setDefaultLang($newlang);
						}
						$desc = (!empty($productsupplier->multilangs[$outputlangs->defaultlang]["description"])) ? $productsupplier->multilangs[$outputlangs->defaultlang]["description"] : $productsupplier->description;
					} else {
						$desc = $productsupplier->description;
					}
					// if we use supplier description of the products
					if (!empty($productsupplier->desc_supplier) && getDolGlobalString('PRODUIT_FOURN_TEXTS')) {
						$desc = $productsupplier->desc_supplier;
					}

					//If text set in desc is the same as product descpription (as now it's preloaded) we add it only one time
					if (trim($product_desc) == trim($desc) && getDolGlobalString('PRODUIT_AUTOFILL_DESC')) {
						$product_desc = '';
					}

					if (!empty($product_desc) && getDolGlobalString('MAIN_NO_CONCAT_DESCRIPTION')) {
						$desc = $product_desc;
					}
					if (!empty($product_desc) && trim($product_desc) != trim($desc)) {
						$desc = dol_concatdesc($desc, $product_desc, false, getDolGlobalString('MAIN_CHANGE_ORDER_CONCAT_DESCRIPTION') ? true : false);
					}

					$ref_supplier = $productsupplier->ref_supplier;

					// Get vat rate
					$tva_npr = 0;
					if (!GETPOSTISSET('tva_tx')) {    // If vat rate not provided from the form (the form has the priority)
						$tmpidprodfournprice = GETPOST('idprodfournprice', 'alpha');    // can be an id of price, or -1, -2, -99 or 'idprod_...'
						if (is_numeric($tmpidprodfournprice) && (int)$tmpidprodfournprice > 0) {
							$tmpidprodfournprice = (int)$tmpidprodfournprice;
						} else {
							$tmpidprodfournprice = 0;
						}

						$tva_tx = get_default_tva($object->thirdparty, $mysoc, $productsupplier->id, $tmpidprodfournprice);
						$tva_npr = get_default_npr($object->thirdparty, $mysoc, $productsupplier->id, $tmpidprodfournprice);
					}
					if (empty($tva_tx)) {
						$tva_npr = 0;
					}
					$localtax1_tx = get_localtax($tva_tx, 1, $mysoc, $object->thirdparty, $tva_npr);
					$localtax2_tx = get_localtax($tva_tx, 2, $mysoc, $object->thirdparty, $tva_npr);

					$type = $productsupplier->type;
					if (GETPOST('price_ht') != '' || GETPOST('multicurrency_price_ht') != '') {
						$price_base_type = 'HT';
						$pu = price2num($price_ht, 'MU');
						$pu_devise = price2num($price_ht_devise, 'CU');
					} elseif (GETPOST('price_ttc') != '' || GETPOST('multicurrency_price_ttc') != '') {
						$price_base_type = 'TTC';
						$pu = price2num($price_ttc, 'MU');
						$pu_devise = price2num($price_ttc_devise, 'CU');
					} else {
						$price_base_type = ($productsupplier->fourn_price_base_type ? $productsupplier->fourn_price_base_type : 'HT');
						if (empty($object->multicurrency_code) || ($productsupplier->fourn_multicurrency_code != $object->multicurrency_code)) {    // If object is in a different currency and price not in this currency
							$pu = $productsupplier->fourn_pu;
							$pu_devise = 0;
						} else {
							$pu = $productsupplier->fourn_pu;
							$pu_devise = $productsupplier->fourn_multicurrency_unitprice;
						}
					}

					if (empty($pu)) {
						$pu = 0; // If pu is '' or null, we force to have a numeric value
					}

					$info_bits = 0;
					if ($tva_npr) {
						$info_bits |= 0x01;
					}

					// If GETPOST('idprodfournprice') is a numeric, we can use it. If it is empty or if it is 'idprod_123', we should use -1 (not used)
					$fournprice = (is_numeric(GETPOST('idprodfournprice', 'alpha')) ? GETPOST('idprodfournprice', 'alpha') : -1);
					$buyingprice = 0;

					$result = $object->addline(
						$desc,
						($price_base_type == 'HT' ? $pu : 0),
						$qty,
						$tva_tx,
						$localtax1_tx,
						$localtax2_tx,
						$productsupplier->id,
						$remise_percent,
						$price_base_type,
						($price_base_type == 'TTC' ? $pu : 0),
						$info_bits,
						$type,
						min($rank, count($object->lines) + 1),
						0, // special_code
						$fournprice,
						$buyingprice,
						$label,
						$array_options,
						$ref_supplier,
						$productsupplier->fk_unit,
						'', // origin
						0, // origin_id
						$date_start,
						$date_end
					);

					//var_dump($tva_tx);
					//var_dump($productsupplier->fourn_pu);
					//var_dump($price_base_type);exit;
					if ($result < 0) {
						$error++;
						setEventMessages($object->error, $object->errors, 'errors');
					}
				}
				if ($idprod == -99 || $idprod == 0) {
					// Product not selected
					$error++;
					$langs->load("errors");
					setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentitiesnoconv("ProductOrService")) . ' ' . $langs->trans("or") . ' ' . $langs->trans("NoPriceDefinedForThisSupplier"), null, 'errors');
				}
				if ($idprod == -1) {
					// Quantity too low
					$error++;
					$langs->load("errors");
					setEventMessages($langs->trans("ErrorQtyTooLowForThisSupplier"), null, 'errors');
				}
			} elseif ((GETPOST('price_ht') !== '' || GETPOST('price_ttc') !== ''/* || GETPOST('multicurrency_price_ht') != ''*/) && empty($error)) {    // Free product.  // $price_ht is already set
				$pu_ht = price2num($price_ht, 'MU');
				$pu_ttc = price2num(GETPOST('price_ttc'), 'MU');

				$tva_npr = (preg_match('/\*/', $tva_tx) ? 1 : 0);
				$tva_tx = str_replace('*', '', $tva_tx);
				$label = (GETPOST('product_label') ? GETPOST('product_label') : '');
				$desc = $product_desc;
				$type = GETPOST('type');

				$fk_unit = GETPOST('units', 'alpha');

				if (!preg_match('/\((.*)\)/', $tva_tx)) {
					$tva_tx = price2num($tva_tx); // $txtva can have format '5,1' or '5.1' or '5.1(XXX)', we must clean only if '5,1'
				}

				// Local Taxes
				$localtax1_tx = get_localtax($tva_tx, 1, $mysoc, $object->thirdparty);
				$localtax2_tx = get_localtax($tva_tx, 2, $mysoc, $object->thirdparty);

				if (GETPOST('price_ht') != ''/* || GETPOST('multicurrency_price_ht') != ''*/) {
					$pu_ht = price2num($price_ht, 'MU'); // $pu_ht must be rounded according to settings
				} else {
					$pu_ttc = price2num(GETPOST('price_ttc'), 'MU');
					$pu_ht = price2num((float)$pu_ttc / (1 + ((float)$tva_tx / 100)), 'MU'); // $pu_ht must be rounded according to settings
				}
				$price_base_type = 'HT';
				$pu_ht_devise = price2num($price_ht_devise, 'CU');
				$info_bits = 0;

				$result = $object->addline(
					$desc,
					$pu_ht,
					$qty,
					$tva_tx,
					$localtax1_tx,
					$localtax2_tx,
					$idprod,
					$remise_percent,
					$price_base_type,
					$pu_ttc,
					$info_bits,
					$type,
					-1, // rang
					0, // special_code
					0, // fk_fournprice
					0, // pa_ht
					$label,
					$array_options,
					$ref_supplier,
					$fk_unit,
					'', // origin
					0, // origin_id
					$date_start,
					$date_end
				);
			}


			if (!$error && $result > 0) {
				$db->commit();

				$ret = $object->fetch($object->id); // Reload to get new records

				// Define output language
				if (!getDolGlobalString('MAIN_DISABLE_PDF_AUTOUPDATE')) {
					$outputlangs = $langs;
					$newlang = '';
					if (getDolGlobalInt('MAIN_MULTILANGS') && empty($newlang) && GETPOST('lang_id', 'aZ09')) {
						$newlang = GETPOST('lang_id', 'aZ09');
					}
					if (getDolGlobalInt('MAIN_MULTILANGS') && empty($newlang)) {
						$newlang = $object->thirdparty->default_lang;
					}
					if (!empty($newlang)) {
						$outputlangs = new Translate("", $conf);
						$outputlangs->setDefaultLang($newlang);
					}
					$model = $object->model_pdf;
					$ret = $object->fetch($id); // Reload to get new records
					if ($ret > 0) {
						$object->fetch_thirdparty();
					}

					$result = $object->generateDocument($model, $outputlangs, $hidedetails, $hidedesc, $hideref);
					if ($result < 0) {
						dol_print_error($db, $object->error, $object->errors);
					}
				}

				unset($_POST['prod_entry_mode']);

				unset($_POST['qty']);
				unset($_POST['type']);
				unset($_POST['remise_percent']);
				unset($_POST['pu']);
				unset($_POST['price_ht']);
				unset($_POST['multicurrency_price_ht']);
				unset($_POST['price_ttc']);
				unset($_POST['fourn_ref']);
				unset($_POST['tva_tx']);
				unset($_POST['label']);
				unset($_POST['product_ref']);
				unset($_POST['product_label']);
				unset($_POST['product_desc']);
				unset($_POST['fournprice']);
				unset($_POST['buying_price']);
				unset($localtax1_tx);
				unset($localtax2_tx);
				unset($_POST['np_marginRate']);
				unset($_POST['np_markRate']);
				unset($_POST['dp_desc']);
				unset($_POST['idprodfournprice']);
				unset($_POST['units']);

				unset($_POST['idprod']);

				unset($_POST['date_starthour']);
				unset($_POST['date_startmin']);
				unset($_POST['date_startsec']);
				unset($_POST['date_startday']);
				unset($_POST['date_startmonth']);
				unset($_POST['date_startyear']);
				unset($_POST['date_endhour']);
				unset($_POST['date_endmin']);
				unset($_POST['date_endsec']);
				unset($_POST['date_endday']);
				unset($_POST['date_endmonth']);
				unset($_POST['date_endyear']);
			} else {
				$db->rollback();

				setEventMessages($object->error, $object->errors, 'errors');
			}
		}
	} elseif ($action == 'updateline' && $user->hasRight('suppliercontract', 'creer') && !GETPOST('cancel', 'alpha')/*GETPOST('save') == $langs->trans("Save")*/) {
		// Update a line within proposal
		$vat_rate = (GETPOST('eltva_tx') ? GETPOST('eltva_tx') : 0);

		// Define info_bits
		$info_bits = 0;
		if (preg_match('/\*/', $vat_rate)) {
			$info_bits |= 0x01;
		}

		// Clean parameters
		$description = dol_htmlcleanlastbr(GETPOST('product_desc', 'restricthtml'));

		// Define vat_rate
		$vat_rate = str_replace('*', '', $vat_rate);
		$localtax1_rate = get_localtax($vat_rate, 1, $mysoc, $object->thirdparty);
		$localtax2_rate = get_localtax($vat_rate, 2, $mysoc, $object->thirdparty);

		$price_base_type = 'HT';
		$ht = price2num(GETPOST('elprice'), '', 2);

		//$pu_ht_devise = price2num(GETPOST('multicurrency_subprice'), 'CU', 2);

		// Add buying price
		$buyingprice = (GETPOST('buying_price') != '' ? GETPOST('buying_price') : ''); // If buying_price is '0', we must keep this value

		// Extrafields Lines
		$extralabelsline = $extrafields->fetch_name_optionals_label($object->table_element_line);
		$array_options = $extrafields->getOptionalsFromPost($object->table_element_line);
		// Unset extrafield POST Data
		if (is_array($extralabelsline)) {
			foreach ($extralabelsline as $key => $value) {
				unset($_POST["options_".$key]);
			}
		}

		// Define special_code for special lines
		$special_code = GETPOST('special_code');
		if (!GETPOST('elqty')) {
			$special_code = 3;
		}

		$line = new SupplierContractLine($db);
		if ($idline > 0) {
			$result = $line->fetch($idline);
			if ($result < 0) {
				setEventMessages($line->error, $line->errors, 'errors');
				$action = 'editline';
				$error++;
			}
		}
		if (empty($line->id)) {
			$langs->load('errors');
			setEventMessages($langs->trans('ErrorRecordNotFound') . ' - Line ID : ' . $idline, null, 'errors');
			$action = 'editline';
			$error++;
		}

		// Check minimum price
		if (!empty($line->fk_product)) {
			$productsupplier = new ProductFournisseur($db);
			if (getDolGlobalString('SUPPLIERCONTRACT_WITH_PREDEFINED_PRICES_ONLY')) {
				if ($productsupplier->get_buyprice($line->fk_fournprice, price2num(GETPOST('elqty'), 'MS', 2), $line->fk_product, 'none', GETPOSTINT('socid')) < 0) {
					setEventMessages($langs->trans("ErrorQtyTooLowForThisSupplier"), null, 'warnings');
				}
			}

			$label = ((GETPOST('update_label') && GETPOST('product_label')) ? GETPOST('product_label') : '');
		} else {
			$label = (GETPOST('product_label') ? GETPOST('product_label') : '');
		}

		if (!empty($date_start_update) && !empty($date_end_update) && $date_start_update > $date_end_update) {
			setEventMessages($langs->trans("Error").': '.$langs->trans("DateStartPlanned").' > '.$langs->trans("DateEndPlanned"), null, 'errors');
			$action = 'editline';
			$error++;
		}

		if (!$error) {
			$db->begin();

			$ref_supplier = GETPOST('elfourn_ref', 'alpha');
			$fk_unit = GETPOST('unit');

			$result = $object->updateline(
				$idline,
				$description,
				$ht,
				price2num(GETPOST('elqty'), 'MS', 2),
				price2num(GETPOST('elremise_percent'), '', 2),
				$date_start_update,
				$date_end_update,
				$vat_rate,
				$localtax1_rate,
				$localtax2_rate,
				$date_start_real_update,
				$date_end_real_update,
				$price_base_type,
				$info_bits,
				$special_code,
				$buyingprice,
				$label,
				$array_options,
				$ref_supplier,
				$fk_unit,
				-1
			);

			if ($result >= 0) {
				$db->commit();

				if (!getDolGlobalString('MAIN_DISABLE_PDF_AUTOUPDATE')) {
					// Define output language
					$outputlangs = $langs;
					if (getDolGlobalInt('MAIN_MULTILANGS')) {
						$outputlangs = new Translate("", $conf);
						$newlang = (GETPOST('lang_id', 'aZ09') ? GETPOST('lang_id', 'aZ09') : $object->thirdparty->default_lang);
						$outputlangs->setDefaultLang($newlang);
					}
					$ret = $object->fetch($id); // Reload to get new records
					$object->generateDocument($object->model_pdf, $outputlangs, $hidedetails, $hidedesc, $hideref);
				}

				unset($_POST['qty']);
				unset($_POST['remise_percent']);
				unset($_POST['price_ht']);
				unset($_POST['multicurrency_price_ht']);
				unset($_POST['price_ttc']);
				unset($_POST['tva_tx']);
				unset($_POST['product_ref']);
				unset($_POST['product_label']);
				unset($_POST['product_desc']);
				unset($_POST['buying_price']);

				unset($_POST['date_starthour']);
				unset($_POST['date_startmin']);
				unset($_POST['date_startsec']);
				unset($_POST['date_startday']);
				unset($_POST['date_startmonth']);
				unset($_POST['date_startyear']);
				unset($_POST['date_endhour']);
				unset($_POST['date_endmin']);
				unset($_POST['date_endsec']);
				unset($_POST['date_endday']);
				unset($_POST['date_endmonth']);
				unset($_POST['date_endyear']);
			} else {
				$db->rollback();

				setEventMessages($object->error, $object->errors, 'errors');
			}
		}
//	} elseif ($action == 'updateline' && $user->hasRight('suppliercontract', 'creer') && GETPOST('cancel', 'alpha') == $langs->trans("Cancel")) {
//		header('Location: '.$_SERVER['PHP_SELF'].'?id='.$object->id); //  To re-display card in edit mode
//		exit();
	} elseif ($action == 'confirm_deleteline' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		$result = $object->deleteLine($user, GETPOSTINT('lineid'));

		if ($result >= 0) {
			header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
			exit;
		} else {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'confirm_valid' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		$result = $object->validate($user);

		if ($result > 0) {
			// Define output language
			if (!getDolGlobalString('MAIN_DISABLE_PDF_AUTOUPDATE')) {
				$outputlangs = $langs;
				$newlang = '';
				if (getDolGlobalInt('MAIN_MULTILANGS') && empty($newlang) && GETPOST('lang_id', 'aZ09')) {
					$newlang = GETPOST('lang_id', 'aZ09');
				}
				if (getDolGlobalInt('MAIN_MULTILANGS') && empty($newlang)) {
					$newlang = $object->thirdparty->default_lang;
				}
				if (!empty($newlang)) {
					$outputlangs = new Translate("", $conf);
					$outputlangs->setDefaultLang($newlang);
				}
				$model = $object->model_pdf;
				$ret = $object->fetch($id); // Reload to get new records

				$object->generateDocument($model, $outputlangs, $hidedetails, $hidedesc, $hideref);
			}
		} else {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'reopen' && $user->hasRight('suppliercontract', 'creer')) {
		$result = $object->reopen($user);
		if ($result < 0) {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'confirm_close' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		// Close all lines
		$result = $object->closeAll($user);
		if ($result < 0) {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'confirm_activate' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		$date_start = dol_mktime(12, 0, 0, GETPOST('d_startmonth'), GETPOST('d_startday'), GETPOST('d_startyear'));
		$date_end   = dol_mktime(12, 0, 0, GETPOST('d_endmonth'), GETPOST('d_endday'), GETPOST('d_endyear'));
		$comment      = GETPOST('comment', 'alpha');
		$result = $object->activateAll($user, $date_start, 0, $comment, $date_end);
		if ($result < 0) {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'confirm_delete' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'supprimer')) {
		$result = $object->delete($user);
		if ($result >= 0) {
			header("Location: list.php?restore_lastsearch_values=1");
			return;
		} else {
			setEventMessages($object->error, $object->errors, 'errors');
		}
	} elseif ($action == 'confirm_move' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		if (GETPOST('newcid') > 0) {
			$suppliercontractline = new SupplierContractLine($db);
			$result = $suppliercontractline->fetch(GETPOSTINT('lineid'));
			$suppliercontractline->fk_suppliercontract = GETPOSTINT('newcid');
			$result = $suppliercontractline->update($user, 1);
			if ($result >= 0) {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$id);
				return;
			} else {
				setEventMessages($object->error, $object->errors, 'errors');
			}
		} else {
			setEventMessages($langs->trans("ErrorFieldRequired", $langs->transnoentities("RefNewSupplierContract")), null, 'errors');
		}
	} elseif ($action == 'update_extras' && $permissiontoadd) {
		$object->oldcopy = dol_clone($object, 2);

		$attribute = GETPOST('attribute', 'alphanohtml');

		// Fill array 'array_options' with data from update form
		$ret = $extrafields->setOptionalsFromPost(null, $object, $attribute);
		if ($ret < 0) {
			setEventMessages($extrafields->error, $object->errors, 'errors');
			$error++;
		}

		if (!$error) {
			$result = $object->updateExtraField($attribute, 'SUPPLIERCONTRACT_MODIFY');
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
				$error++;
			}
		}

		if ($error) {
			$action = 'edit_extras';
		}
	} elseif ($action == 'setref_supplier' && $permissiontoadd) {
		if (!$cancel) {
			$object->oldcopy = dol_clone($object, 2);

			$result = $object->setValueFrom('ref_supplier', GETPOST('ref_supplier', 'alpha'), '', null, 'text', '', $user, 'SUPPLIERCONTRACT_MODIFY');
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
				$action = 'editref_supplier';
			} else {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			}
		} else {
			header("Location: ".$_SERVER['PHP_SELF']."?id=".$id);
			exit;
		}
	} elseif ($action == 'setref_customer' && $permissiontoadd) {
		if (!$cancel) {
			$object->oldcopy = dol_clone($object, 2);

			$result = $object->setValueFrom('ref_customer', GETPOST('ref_customer', 'alpha'), '', null, 'text', '', $user, 'SUPPLIERCONTRACT_MODIFY');
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
				$action = 'editref_customer';
			} else {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			}
		} else {
			header("Location: ".$_SERVER['PHP_SELF']."?id=".$id);
			exit;
		}
	} elseif ($action == 'setref' && $permissiontoadd) {
		if (!$cancel) {
			$result = $object->fetch($id);
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
			}

			$old_ref = $object->ref;

			$result = $object->setValueFrom('ref', GETPOST('ref', 'alpha'), '', null, 'text', '', $user, 'SUPPLIERCONTRACT_MODIFY');
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
				$action = 'editref';
			} else {
				require_once DOL_DOCUMENT_ROOT.'/core/lib/files.lib.php';
				$old_filedir = $conf->suppliercontract->multidir_output[$object->entity].'/'.dol_sanitizeFileName($old_ref);
				$new_filedir = $conf->suppliercontract->multidir_output[$object->entity].'/'.dol_sanitizeFileName($object->ref);

				// Rename directory of supplier contract with new name
				dol_move_dir($old_filedir, $new_filedir);

				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			}
		} else {
			header("Location: ".$_SERVER['PHP_SELF']."?id=".$id);
			exit;
		}
	} elseif ($action == 'setdate_contract' && $permissiontoadd) {
		if (!$cancel) {
			$result = $object->fetch($id);
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
			}
			$datacontract = dol_mktime(GETPOST('date_contracthour'), GETPOST('date_contractmin'), 0, GETPOST('date_contractmonth'), GETPOST('date_contractday'), GETPOST('date_contractyear'));
			$result = $object->setValueFrom('date_contract', $datacontract, '', null, 'date', '', $user, 'SUPPLIERCONTRACT_MODIFY');
			if ($result < 0) {
				setEventMessages($object->error, $object->errors, 'errors');
				$action = 'editdate_contract';
			} else {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			}
		} else {
			header("Location: ".$_SERVER['PHP_SELF']."?id=".$id);
			exit;
		}
	}

	// Actions when printing a doc from card
	include DOL_DOCUMENT_ROOT.'/core/actions_printing.inc.php';

	// Actions to build doc
	$upload_dir = $conf->suppliercontract->multidir_output[!empty($object->entity) ? $object->entity : $conf->entity];
	include DOL_DOCUMENT_ROOT.'/core/actions_builddoc.inc.php';

	// Actions to send emails
	$triggersendname = 'SUPPLIERCONTRACT_SENTBYMAIL';
	$paramname = 'id';
	$mode = 'emailfromsuppliercontract';
	$trackid = 'con'.$object->id;
	include DOL_DOCUMENT_ROOT.'/core/actions_sendmails.inc.php';


	if (getDolGlobalString('MAIN_DISABLE_CONTACTS_TAB')) {
		if ($action == 'addcontact' && $user->hasRight('suppliercontract', 'creer')) {
			$contactid = (GETPOST('userid') ? GETPOST('userid') : GETPOST('contactid'));
			$typeid = (GETPOST('typecontact') ? GETPOST('typecontact') : GETPOST('type'));
			$result = $object->add_contact($contactid, $typeid, GETPOST("source", 'aZ09'));

			if ($result >= 0) {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			} else {
				if ($object->error == 'DB_ERROR_RECORD_ALREADY_EXISTS') {
					$langs->load("errors");
					setEventMessages($langs->trans("ErrorThisContactIsAlreadyDefinedAsThisType"), null, 'errors');
				} else {
					setEventMessages($object->error, $object->errors, 'errors');
				}
			}
		} elseif ($action == 'swapstatus' && $user->hasRight('suppliercontract', 'creer')) {
			// bascule du statut d'un contact
			$result = $object->swapContactStatus(GETPOSTINT('ligne'));
		} elseif ($action == 'deletecontact' && $user->hasRight('suppliercontract', 'creer')) {
			// Efface un contact
			$result = $object->delete_contact(GETPOSTINT('lineid'));

			if ($result >= 0) {
				header("Location: ".$_SERVER['PHP_SELF']."?id=".$object->id);
				exit;
			} else {
				setEventMessages($object->error, $object->errors, 'errors');
			}
		}
	}

	// Action clone object
	if ($action == 'confirm_clone' && $confirm == 'yes' && $user->hasRight('suppliercontract', 'creer')) {
		if (!GETPOSTINT('socid', 3)) {
			setEventMessages($langs->trans("NoCloneOptionsSpecified"), null, 'errors');
		} else {
			if ($object->id > 0) {
				$result = $object->createFromClone($user, $socid);
				if ($result > 0) {
					header("Location: ".$_SERVER['PHP_SELF'].'?id='.$result);
					exit();
				} else {
					if (count($object->errors) > 0) {
						setEventMessages($object->error, $object->errors, 'errors');
					}
					$action = '';
				}
			}
		}
	}
}


/*
 * View
 */

$title = $object->ref." - ".$langs->trans('SupplierContract');
if ($action == 'create') {
	$title = $langs->trans("NewSupplierContract");
}
$help_url = 'EN:Module_SupplierContracts|FR:Module_ContratsFournisseur|ES:Contratos_de_proveedor';

llxHeader('', $title, $help_url, '', 0, 0, '', '', '', 'mod-suppliercontract page-card');

$form = new Form($db);
$formfile = new FormFile($db);
if (isModEnabled('project')) {
	$formproject = new FormProjets($db);
}

// Load object modSupplierContract
$module = (getDolGlobalString('SUPPLIERCONTRACT_ADDON') ? $conf->global->SUPPLIERCONTRACT_ADDON : 'mod_suppliercontract_serpis');
if (substr($module, 0, 13) == 'mod_suppliercontract_' && substr($module, -3) == 'php') {
	$module = substr($module, 0, dol_strlen($module) - 4);
}
$result = dol_include_once('/suppliercontract/core/modules/suppliercontract/'.$module.'.php');
$modCodeSupplierContract = null;
if ($result > 0) {
	$modCodeSupplierContract = new $module();
	'@phan-var-force ModelNumRefSupplierContracts $modCodeSupplierContract';
}

// Create
if ($action == 'create') {
	$objectsrc = null;
	print load_fiche_titre($langs->trans('NewSupplierContract'), '', 'contract');

	$soc = new Societe($db);
	if ($socid > 0) {
		$soc->fetch($socid);
	}

	if (GETPOST('origin') && GETPOSTINT('originid')) {
		$origin = GETPOST('origin');

		if ($origin == 'project') {
			$projectid = GETPOSTINT('originid');
		} else {
			$objectsrc = fetchObjectByElement($originid, $origin);
			'@phan-var-force CommandeFournisseur|SupplierProposal|FactureFournisseur $objectsrc';
			if (empty($objectsrc->lines) && method_exists($objectsrc, 'fetch_lines')) {
				$objectsrc->fetch_lines();
			}
			$objectsrc->fetch_thirdparty();

			// Replicate extrafields
			$objectsrc->fetch_optionals();
			$object->array_options = $objectsrc->array_options;

			$projectid = (!empty($objectsrc->fk_project) ? $objectsrc->fk_project : '');

			$soc = $objectsrc->thirdparty;

			$note_private = (!empty($objectsrc->note_private) ? $objectsrc->note_private : '');
			$note_public = (!empty($objectsrc->note_public) ? $objectsrc->note_public : '');

			// Object source contacts list
			$srccontactslist = $objectsrc->liste_contact(-1, 'external', 1);
		}
	} else {
		$projectid = GETPOSTINT('projectid');
		$note_private = GETPOST("note_private", "alpha");
		$note_public = GETPOST("note_public", "alpha");
	}

	$object->date_contract = dol_now();

	print '<form name="form_suppliercontract" action="'.$_SERVER["PHP_SELF"].'" method="post">';
	print '<input type="hidden" name="token" value="'.newToken().'">';
	print '<input type="hidden" name="action" value="add">';
	print '<input type="hidden" name="socid" value="'.$soc->id.'">'."\n";
	print '<input type="hidden" name="remise_percent" value="0">';
	print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';

	print dol_get_fiche_head();

	print '<table class="border centpercent">';

	// Ref
	print '<tr><td class="titlefieldcreate fieldrequired">'.$langs->trans('Ref').'</td><td>';
	if (!empty($modCodeSupplierContract->code_auto)) {
		$tmpcode = $langs->trans("Draft");
	} else {
		$tmpcode = '<input name="ref" class="maxwidth100" maxlength="128" value="'.dol_escape_htmltag(GETPOST('ref') ? GETPOST('ref') : $tmpcode).'">';
	}
	print $tmpcode;
	print '</td></tr>';

	// Ref customer
	print '<tr><td>'.$langs->trans('RefCustomer').'</td>';
	print '<td><input type="text" class="maxwidth150" name="ref_customer" id="ref_customer" value="'.dol_escape_htmltag(GETPOST('ref_customer', 'alpha')).'"></td></tr>';

	// Ref supplier
	print '<tr><td>'.$langs->trans('RefSupplier').'</td>';
	print '<td><input type="text" class="maxwidth150" name="ref_supplier" id="ref_supplier" value="'.dol_escape_htmltag(GETPOST('ref_supplier', 'alpha')).'"></td></tr>';

	// Thirdparty
	print '<tr>';
	print '<td class="fieldrequired">'.$langs->trans('ThirdParty').'</td>';
	if ($socid > 0) {
		print '<td>';
		print $soc->getNomUrl(1);
		print '<input type="hidden" name="socid" value="'.$soc->id.'">';
		print '</td>';
	} else {
		print '<td>';
		print img_picto('', 'company', 'class="pictofixedwidth"');
		print $form->select_company('', 'socid', '(s.fournisseur:=:1)', 'SelectThirdParty', 0, 0, array(), 0, 'minwidth300 widthcentpercentminusxx maxwidth500');
		print ' <a href="'.DOL_URL_ROOT.'/societe/card.php?action=create&backtopage='.urlencode($_SERVER["PHP_SELF"].'?action=create').'"><span class="fa fa-plus-circle valignmiddle paddingleft" title="'.$langs->trans("AddThirdParty").'"></span></a>';
		print '</td>';
	}
	print '</tr>'."\n";

	if ($socid > 0) {
		// Ligne info remises tiers
		print '<tr><td>'.$langs->trans('Discounts').'</td><td>';
		if ($soc->remise_percent) {
			print $langs->trans("CompanyHasRelativeDiscount", $soc->remise_percent).' ';
		} else {
			print '<span class="hideonsmartphone">'.$langs->trans("CompanyHasNoRelativeDiscount").'. </span>';
		}
		$absolute_discount = $soc->getAvailableDiscounts();
		if ($absolute_discount) {
			print $langs->trans("CompanyHasAbsoluteDiscount", price($absolute_discount), $langs->trans("Currency".$conf->currency)).'.';
		} else {
			print '<span class="hideonsmartphone">'.$langs->trans("CompanyHasNoAbsoluteDiscount").'.</span>';
		}
		print '</td></tr>';
	}

	// Commercial suivi
	print '<tr><td class="nowrap"><span class="fieldrequired">'.$langs->trans("TypeContact_suppliercontract_internal_SALESREPFOLL").'</span></td><td>';
	print img_picto('', 'user', 'class="pictofixedwidth"');
	print $form->select_dolusers(GETPOST("commercial_suivi_id") ? GETPOST("commercial_suivi_id") : $user->id, 'commercial_suivi_id', 1, '');
	print '</td></tr>';

	// Commercial signature
	print '<tr><td class="nowrap"><span class="fieldrequired">'.$langs->trans("TypeContact_suppliercontract_internal_SALESREPSIGN").'</span></td><td>';
	print img_picto('', 'user', 'class="pictofixedwidth"');
	print $form->select_dolusers(GETPOST("commercial_signature_id") ? GETPOST("commercial_signature_id") : $user->id, 'commercial_signature_id', 1, '');
	print '</td></tr>';

	print '<tr><td><span class="fieldrequired">'.$langs->trans("Date").'</span></td><td>';
	print img_picto('', 'action', 'class="pictofixedwidth"');
	print $form->selectDate($datecontract, '', 0, 0, 0, "suppliercontract");
	print "</td></tr>";

	// Project
	if (isModEnabled('project')) {
		$langs->load('projects');

		$formproject = new FormProjets($db);

		print '<tr><td>'.$langs->trans("Project").'</td><td>';
		print img_picto('', 'project', 'class="pictofixedwidth"');
		$formproject->select_projects(($soc->id > 0 ? $soc->id : -1), $projectid, "projectid", 0, 0, 1, 1);
		print ' &nbsp; <a href="'.DOL_URL_ROOT.'/projet/card.php?socid='.$soc->id.'&action=create&status=1&backtopage='.urlencode($_SERVER["PHP_SELF"].'?action=create&socid='.$soc->id).'"><span class="fa fa-plus-circle valignmiddle" title="'.$langs->trans("AddProject").'"></span></a>';
		print "</td></tr>";
	}

	print '<tr><td>'.$langs->trans("NotePublic").'</td><td class="tdtop">';
	$doleditor = new DolEditor('note_public', $note_public, '', 100, 'dolibarr_notes', 'In', 1, true, !getDolGlobalString('FCKEDITOR_ENABLE_NOTE_PUBLIC') ? 0 : 1, ROWS_3, '90%');
	print $doleditor->Create(1);
	print '</td></tr>';

	if (empty($user->socid)) {
		print '<tr><td>'.$langs->trans("NotePrivate").'</td><td class="tdtop">';
		$doleditor = new DolEditor('note_private', $note_private, '', 100, 'dolibarr_notes', 'In', 1, true, !getDolGlobalString('FCKEDITOR_ENABLE_NOTE_PRIVATE') ? 0 : 1, ROWS_3, '90%');
		print $doleditor->Create(1);
		print '</td></tr>';
	}

	// Other attributes
	$parameters = array('objectsrc' => $objectsrc, 'colspan' => ' colspan="3"', 'cols' => '3');
	$reshook = $hookmanager->executeHooks('formObjectOptions', $parameters, $object, $action); // Note that $action and $object may have been modified by hook
	print $hookmanager->resPrint;

	// Other attributes
	if (empty($reshook)) {
		print $object->showOptionals($extrafields, 'create', $parameters);
	}

	print "</table>\n";

	print dol_get_fiche_end();

	print $form->buttonsSaveCancel("Create");

	if (is_object($objectsrc)) {
		print '<input type="hidden" name="origin"         value="'.$objectsrc->element.'">';
		print '<input type="hidden" name="originid"       value="'.$objectsrc->id.'">';

		if (!getDolGlobalString('SUPPLIERCONTRACT_SUPPORT_PRODUCTS')) {
			print '<br>'.$langs->trans("Note").': '.$langs->trans("OnlyLinesWithTypeServiceAreUsed");
		}
	}

	print "</form>\n";
} else {
	// View and edit mode
	$now = dol_now();

	if ($object->id > 0) {
		$object->fetch_thirdparty();

		$soc = $object->thirdparty; // $soc is used later

		$result = $object->fetch_lines(); // This also init $this->nbofserviceswait, $this->nbofservicesopened, $this->nbofservicesexpired=, $this->nbofservicesclosed
		if ($result < 0) {
			dol_print_error($db, $object->errorsToString());
		}

		$nbofservices = count($object->lines);

		$author = new User($db);
		$author->fetch($object->user_author_id);

		$head = supplierContractPrepareHead($object);

		$hselected = '0';
		$formconfirm = '';

		print dol_get_fiche_head($head, $hselected, $langs->trans("SupplierContract"), -1, 'contract');


		if ($action == 'delete') {
			//Confirmation de la suppression du contrat fournisseur
			$formconfirm = $form->formconfirm($_SERVER['PHP_SELF']."?id=".$object->id, $langs->trans("DeleteASupplierContract"), $langs->trans("ConfirmDeleteASupplierContract"), "confirm_delete", '', 0, 1);
		} elseif ($action == 'valid') {
			//Confirmation de la validation
			$ref = substr($object->ref, 1, 4);
			if ($ref == 'PROV' && !empty($modCodeSupplierContract->code_auto)) {
				$numref = $object->getNextNumRef($object->thirdparty);
			} else {
				$numref = $object->ref;
			}
			$text = $langs->trans('ConfirmValidateSupplierContract', $numref);
			$formconfirm = $form->formconfirm($_SERVER['PHP_SELF']."?id=".$object->id, $langs->trans("ValidateASupplierContract"), $text, "confirm_valid", '', 0, 1);
		} elseif ($action == 'close') {
			// Confirmation de la fermeture
			$formconfirm = $form->formconfirm($_SERVER['PHP_SELF']."?id=".$object->id, $langs->trans("CloseASupplierContract"), $langs->trans("ConfirmCloseSupplierContract"), "confirm_close", '', 0, 1);
		} elseif ($action == 'activate') {
			$formquestion = array(
				array('type' => 'date', 'name' => 'd_start', 'label' => $langs->trans("DateServiceActivate"), 'value' => dol_now()),
				array('type' => 'date', 'name' => 'd_end', 'label' => $langs->trans("DateEndPlanned"), /*'value' => $form->selectDate('', "end", $usehm, $usehm, '', "active", 1, 0),*/ 0 => '', 1 => ''),
				array('type' => 'text', 'name' => 'comment', 'label' => $langs->trans("Comment"), 'value' => '', 0 => '', 1 => '', 'class' => 'minwidth300', 'moreattr' => 'autofocus')
			);
			$formconfirm = $form->formconfirm($_SERVER['PHP_SELF']."?id=".$object->id, $langs->trans("ActivateAllOnSupplierContract"), $langs->trans("ConfirmActivateAllOnSupplierContract"), "confirm_activate", $formquestion, 'yes', 1, 280);
		} elseif ($action == 'clone') {
			$filter = '(s.fournisseur:=:1)';
			// Clone confirmation
			$formquestion = array(array('type' => 'other', 'name' => 'socid', 'label' => $langs->trans("SelectThirdParty"), 'value' => $form->select_company(GETPOSTINT('socid'), 'socid', $filter)));
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('ToClone'), $langs->trans('ConfirmCloneSupplierContract', $object->ref), 'confirm_clone', $formquestion, 'yes', 1);
		} elseif ($action == 'sign') {
			$text = $langs->trans('ConfirmSignSupplierContract');
			if (isModEnabled('notification')) {
				require_once DOL_DOCUMENT_ROOT.'/core/class/notify.class.php';
				$notify = new Notify($db);
				$text .= '<br>';
				$text .= $notify->confirmMessage('SUPPLIERCONTRACT_MODIFY', $object->socid, $object);
			}
			$formquestion = [];
			$formquestion[] = [
				'type' 		=> 'select',
				'name' 		=> 'signed_status',
				'label'		=> '<span class="fieldrequired">'.$langs->trans('SignStatus').'</span>',
				'values'	=> $object->getSignedStatusLocalisedArray()
			];
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('SignSupplierContract'), $text, 'confirm_sign', $formquestion, 0, 1);
		} elseif ($action == 'unsign') {
			$text = $langs->trans('ConfirmUnsignSupplierContract');
			if (isModEnabled('notification')) {
				require_once DOL_DOCUMENT_ROOT.'/core/class/notify.class.php';
				$notify = new Notify($db);
				$text .= '<br>';
				$text .= $notify->confirmMessage('SUPPLIERCONTRACT_MODIFY', $object->socid, $object);
			}
			$formconfirm = $form->formconfirm($_SERVER["PHP_SELF"].'?id='.$object->id, $langs->trans('UnsignSupplierContract'), $text, 'confirm_unsign', '', 0, 1);
		}


		// Call Hook formConfirm
		$parameters = array(
			'formConfirm' => $formconfirm,
			'id' => $id,
			//'lineid' => $lineid,
		);
		// Note that $action and $object may have been modified by hook
		$reshook = $hookmanager->executeHooks('formConfirm', $parameters, $object, $action);
		if (empty($reshook)) {
			$formconfirm .= $hookmanager->resPrint;
		} elseif ($reshook > 0) {
			$formconfirm = $hookmanager->resPrint;
		}

		// Print form confirm
		print $formconfirm;


		// Supplier Contract
		if ($object->status == $object::STATUS_DRAFT && $user->hasRight('suppliercontract', 'creer')) {
			print '<form action="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'" method="POST">';
			print '<input type="hidden" name="token" value="'.newToken().'">';
			print '<input type="hidden" name="action" value="setremise">';
			print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';
		}

		// Supplier Contract card

		$linkback = '<a href="'.dol_buildpath('/suppliercontract/list.php',1).'?restore_lastsearch_values=1'.(!empty($socid) ? '&socid='.$socid : '').'">'.$langs->trans("BackToList").'</a>';


		$morehtmlref = '';
		if (!empty($modCodeSupplierContract->code_auto)) {
			$morehtmlref .= $object->ref;
		} else {
			$morehtmlref .= $form->editfieldkey("", 'ref', $object->ref, $object, $user->hasRight('suppliercontract', 'creer'), 'string', '', 0, 3);
			$morehtmlref .= $form->editfieldval("", 'ref', $object->ref, $object, $user->hasRight('suppliercontract', 'creer'), 'string', '', null, 2);
		}

		$morehtmlref .= '<div class="refidno">';
		// Ref customer
		$morehtmlref .= $form->editfieldkey("RefCustomer", 'ref_customer', $object->ref_customer, $object, $user->hasRight('suppliercontract', 'creer'), 'string', '', 0, 1);
		$morehtmlref .= $form->editfieldval("RefCustomer", 'ref_customer', $object->ref_customer, $object, $user->hasRight('suppliercontract', 'creer'), 'string'.(isset($conf->global->THIRDPARTY_REF_INPUT_SIZE) ? ':' . getDolGlobalString('THIRDPARTY_REF_INPUT_SIZE') : ''), '', null, null, '', 1, 'getFormatedCustomerRef');
		// Ref supplier
		$morehtmlref .= '<br>';
		$morehtmlref .= $form->editfieldkey("RefSupplier", 'ref_supplier', $object->ref_supplier, $object, $user->hasRight('suppliercontract', 'creer'), 'string', '', 0, 1);
		$morehtmlref .= $form->editfieldval("RefSupplier", 'ref_supplier', $object->ref_supplier, $object, $user->hasRight('suppliercontract', 'creer'), 'string', '', null, null, '', 1, 'getFormatedSupplierRef');
		// Thirdparty
		$morehtmlref .= '<br>'.$object->thirdparty->getNomUrl(1);
		if (!getDolGlobalString('MAIN_DISABLE_OTHER_LINK') && $object->thirdparty->id > 0) {
			$morehtmlref .= ' <span class="otherlink">(<a href="'.dol_buildpath('/suppliercontract/list.php',1).'?socid='.$object->thirdparty->id.'&search_name='.urlencode($object->thirdparty->name).'">'.$langs->trans("OtherSupplierContracts").'</a>)</span>';
		}
		// Project
		if (isModEnabled('project')) {
			$langs->load("projects");
			$morehtmlref .= '<br>';
			if ($permissiontoadd) {
				$morehtmlref .= img_picto($langs->trans("Project"), 'project', 'class="pictofixedwidth"');
				if ($action != 'classify') {
					$morehtmlref .= '<a class="editfielda" href="'.$_SERVER['PHP_SELF'].'?action=classify&token='.newToken().'&id='.$object->id.'">'.img_edit($langs->transnoentitiesnoconv('SetProject')).'</a> ';
				}
				$morehtmlref .= $form->form_project($_SERVER['PHP_SELF'].'?id='.$object->id, $object->socid, $object->fk_project, ($action == 'classify' ? 'projectid' : 'none'), 0, 0, 0, 1, '', 'maxwidth300');
			} else {
				if (!empty($object->fk_project)) {
					$proj = new Project($db);
					$proj->fetch($object->fk_project);
					$morehtmlref .= $proj->getNomUrl(1);
					if ($proj->title) {
						$morehtmlref .= '<span class="opacitymedium"> - '.dol_escape_htmltag($proj->title).'</span>';
					}
				}
			}
		}
		$morehtmlref .= '</div>';


		dol_banner_tab($object, 'ref', $linkback, 1, 'ref', 'none', $morehtmlref);


		print '<div class="fichecenter">';
		print '<div class="underbanner clearboth"></div>';


		print '<table class="border tableforfield" width="100%">';

		// Line info of thirdparty discounts
		print '<tr><td class="titlefield">'.$langs->trans('Discount').'</td><td colspan="3">';
		if ($object->thirdparty->remise_percent) {
			print $langs->trans("CompanyHasRelativeDiscount", $object->thirdparty->remise_percent).'. ';
		} else {
			print '<span class="hideonsmartphone">'.$langs->trans("CompanyHasNoRelativeDiscount").'. </span>';
		}
		$absolute_discount = $object->thirdparty->getAvailableDiscounts();
		if ($absolute_discount) {
			print $langs->trans("CompanyHasAbsoluteDiscount", price($absolute_discount), $langs->trans("Currency".$conf->currency)).'.';
		} else {
			print '<span class="hideonsmartphone">'.$langs->trans("CompanyHasNoAbsoluteDiscount").'.</span>';
		}
		print '</td></tr>';

		// Date
		print '<tr>';
		print '<td class="titlefield">';
		print $form->editfieldkey("Date", 'date_contract', $object->date_contract, $object, $user->hasRight('suppliercontract', 'creer'));
		print '</td><td>';
		print $form->editfieldval("Date", 'date_contract', $object->date_contract, $object, $user->hasRight('suppliercontract', 'creer'), 'datehourpicker');
		print '</td>';
		print '</tr>';

		// Other attributes
		$cols = 3;
		include DOL_DOCUMENT_ROOT.'/core/tpl/extrafields_view.tpl.php';

		print "</table>";

		print '</div>';

		if ($object->status == $object::STATUS_DRAFT && $user->hasRight('suppliercontract', 'creer')) {
			print '</form>';
		}

		echo '<br>';

		if (getDolGlobalString('MAIN_DISABLE_CONTACTS_TAB')) {
			$blocname = 'contacts';
			$title = $langs->trans('ContactsAddresses');
			include DOL_DOCUMENT_ROOT.'/core/tpl/bloc_showhide.tpl.php';
		}

		if (getDolGlobalString('MAIN_DISABLE_NOTES_TAB')) {
			$blocname = 'notes';
			$title = $langs->trans('Notes');
			include DOL_DOCUMENT_ROOT.'/core/tpl/bloc_showhide.tpl.php';
		}


		$arrayothersuppliercontracts = $object->getListOfContracts('others');	// array or -1 if technical error

		/*
		 * Lines of supplier contracts
		 */

		// Add products/services form
		global $forceall, $senderissupplier, $dateSelector, $inputalsopricewithtax;
		$forceall = 1;
		$dateSelector = 1;
		$inputalsopricewithtax = 1;
		$senderissupplier = 2; // $senderissupplier=2 is same than 1 but disable test on minimum qty and disable autofill qty with minimum.
		if (getDolGlobalString('SUPPLIERCONTRACT_WITH_PREDEFINED_PRICES_ONLY')) {
			$senderissupplier = 1;
		}

		$productstatic = new Product($db);

		// Title line for service
		$cursorline = 1;


		print '<div id="suppliercontract-lines-container" data-suppliercontractid="'.$object->id.'"  data-element="'.$object->element.'" >';
		while ($cursorline <= $nbofservices) {
			print '<div id="suppliercontract-line-container'.$object->lines[$cursorline - 1]->id.'" data-suppliercontractlineid = "'.$object->lines[$cursorline - 1]->id.'" data-element="'.$object->lines[$cursorline - 1]->element.'" >';
			print '<form name="update" id="addproduct" action="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'" method="post">';
			print '<input type="hidden" name="token" value="'.newToken().'">';
			print '<input type="hidden" name="action" value="updateline">';
			print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';
			print '<input type="hidden" name="elrowid" value="'.$object->lines[$cursorline - 1]->id.'">';
			print '<input type="hidden" name="fournprice" value="'.(!empty($object->lines[$cursorline - 1]->fk_fournprice) ? $object->lines[$cursorline - 1]->fk_fournprice : 0).'">';

			// Area with common detail of line
			print '<div class="div-table-responsive-no-min">';
			print '<table class="notopnoleftnoright allwidth tableforservicepart1 centpercent">';

			$sql = "SELECT cd.rowid, cd.status, cd.label as label_det, cd.fk_product, cd.product_type, cd.description, cd.price_ht, cd.qty,";
			$sql .= " cd.tva_tx, cd.vat_src_code, cd.remise_percent, cd.info_bits, cd.subprice, cd.multicurrency_subprice,";
			$sql .= " cd.date_planned_opening as date_start, cd.date_opening as date_start_real,";
			$sql .= " cd.date_expiry as date_end, cd.date_cloture as date_end_real,";
			$sql .= " cd.comment as comment, cd.ref_supplier, cd.fk_product_fournisseur_price as fk_fournprice, cd.buy_price_ht as pa_ht,";
			$sql .= " cd.fk_unit,";
			$sql .= " p.rowid as pid, p.ref as pref, p.label as plabel, p.fk_product_type as ptype, p.entity as pentity, p.tosell, p.tobuy, p.tobatch";
			$sql .= " ,cd.rang";
			$sql .= " FROM ".MAIN_DB_PREFIX."suppliercontractdet as cd";
			$sql .= " LEFT JOIN ".MAIN_DB_PREFIX."product as p ON cd.fk_product = p.rowid";
			$sql .= " WHERE cd.rowid = ".((int) $object->lines[$cursorline - 1]->id);

			$result = $db->query($sql);
			$objp = null;
			if ($result) {
				$total = 0;

				$objp = $db->fetch_object($result);

				// Line title
				print '<tr class="liste_titre'.($cursorline ? ' liste_titre_add' : '').'">';
				print '<td>'.$langs->trans("ServiceNb", $cursorline).'</td>';
				print '<td class="linerefsupplier maxwidth125"><span id="title_fourn_ref">'.$langs->trans("SupplierRef").'</span></td>';
				print '<td width="80" class="center">'.$langs->trans("VAT").'</td>';
				print '<td width="80" class="right">'.$langs->trans("PriceUHT").'</td>';
				//if (isModEnabled("multicurrency")) {
				//	print '<td width="80" class="right">'.$langs->trans("PriceUHTCurrency").'</td>';
				//}
				print '<td width="30" class="center">'.$langs->trans("Qty").'</td>';
				if (getDolGlobalInt('PRODUCT_USE_UNITS')) {
					print '<td width="30" class="left">'.$langs->trans("Unit").'</td>';
				}
				print '<td width="50" class="right">'.$langs->trans("ReductionShort").'</td>';

				if ($nbofservices > 1 && $conf->browser->layout != 'phone' && $user->hasRight('suppliercontract', 'creer')) {
					print '<td width="30" class="linecolmove tdlineupdown center">';
					if ($cursorline > 1) {
						print '<a class="lineupdown reposition" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&action=up&token='.newToken().'&rowid='.$objp->rowid.'">';
						echo img_up('default', 0, 'imgupforline');
						print '</a>';
					}
					if ($cursorline < $nbofservices) {
						print '<a class="lineupdown reposition" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&action=down&token='.newToken().'&rowid='.$objp->rowid.'">';
						echo img_down('default', 0, 'imgdownforline');
						print '</a>';
					}
					print '</td>';
				} else {
					print '<td width="30">&nbsp;</td>';
				}

				print "</tr>\n";



				// Line in view mode
				if ($action != 'editline' || $idline != $objp->rowid) {
					$moreparam = '';
					if (getDolGlobalString('SUPPLIERCONTRACT_HIDE_CLOSED_SERVICES_BY_DEFAULT') && $objp->status == SupplierContractLine::STATUS_CLOSED && $action != 'showclosedlines') {
						$moreparam = 'style="display: none;"';
					}

					print '<tr class="tdtop oddeven" '.$moreparam.'>';

					// Label
					if ($objp->fk_product > 0) {
						$productstatic->id = $objp->fk_product;
						$productstatic->type = $objp->ptype;
						$productstatic->ref = $objp->pref;
						$productstatic->entity = $objp->pentity;
						$productstatic->label = $objp->plabel;
						$productstatic->status = $objp->tosell;
						$productstatic->status_buy = $objp->tobuy;
						$productstatic->status_batch = $objp->tobatch;

						print '<td>';
						$text = $productstatic->getNomUrl(1, '', 32);
						if ($objp->plabel) {
							$text .= ' - ';
							$text .= $objp->plabel;
						}
						$description = $objp->description;

						// Add description in form
						if (getDolGlobalInt('PRODUIT_DESC_IN_FORM_ACCORDING_TO_DEVICE')) {
							$text .= (!empty($objp->description) && $objp->description != $objp->plabel) ? '<br>'.dol_htmlentitiesbr($objp->description) : '';
							$description = ''; // Already added into main visible desc
						}

						print $form->textwithtooltip($text, $description, 3, 0, 0, $cursorline, 3, (!empty($line->fk_parent_line) ? img_picto('', 'rightarrow') : ''));

						print '</td>';
					} else {
						print '<td>'.img_object($langs->trans("ShowProductOrService"), ($objp->product_type ? 'service' : 'product')).' '.dol_htmlentitiesbr($objp->description)."</td>\n";
					}
					// Ref supplier
					print '<td>';
					print $objp->ref_supplier;
					print '</td>';
					// VAT
					print '<td class="center">';
					print vatrate($objp->tva_tx.($objp->vat_src_code ? (' ('.$objp->vat_src_code.')') : ''), true, $objp->info_bits);
					print '</td>';
					// Price
					print '<td class="right">'.($objp->subprice != '' ? price($objp->subprice) : '')."</td>\n";
					// Price multicurrency
					/*if (isModEnabled("multicurrency")) {
						print '<td class="linecoluht_currency nowrap right">'.price($objp->multicurrency_subprice).'</td>';
					}*/
					// Quantity
					print '<td class="center">'.$objp->qty.'</td>';
					// Unit
					if (getDolGlobalInt('PRODUCT_USE_UNITS')) {
						print '<td class="left">'.$langs->trans($object->lines[$cursorline - 1]->getLabelOfUnit()).'</td>';
					}
					// Discount
					if ($objp->remise_percent > 0) {
						print '<td class="right">'.$objp->remise_percent."%</td>\n";
					} else {
						print '<td>&nbsp;</td>';
					}

					// Icon move, update et delete (status supplier contract 0=draft,1=validated,2=closed)
					print '<td class="nowraponall right">';
					if ($user->hasRight('suppliercontract', 'creer') && is_array($arrayothersuppliercontracts) && count($arrayothersuppliercontracts) && ($object->status >= 0)) {
						print '<!-- link to move service line into another supplier contract -->';
						print '<a class="reposition marginrightonly" style="padding-left: 5px;" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&action=move&token='.newToken().'&elrowid='.$objp->rowid.'">';
						print img_picto($langs->trans("MoveToAnotherSupplierContract"), 'uparrow');
						print '</a>';
					}
					if ($user->hasRight('suppliercontract', 'creer') && ($object->status >= 0)) {
						print '<a class="reposition marginrightonly editfielda" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&action=editline&token='.newToken().'&elrowid='.$objp->rowid.'">';
						print img_edit();
						print '</a>';
					}
					if ($user->hasRight('suppliercontract', 'creer') && ($object->status >= 0)) {
						print '<a class="reposition marginrightonly" href="'.$_SERVER['PHP_SELF'].'?id='.$object->id.'&action=deleteline&token='.newToken().'&elrowid='.$objp->rowid.'">';
						print img_delete();
						print '</a>';
					}
					print '</td>';

					print "</tr>\n";

					$colspan = 7;
					if (getDolGlobalInt('PRODUCT_USE_UNITS')) {
						$colspan++;
					}

					// Dates of service planned and real
					if ($objp->subprice >= 0) {
						print '<tr class="oddeven" '.$moreparam.'>';
						print '<td colspan="'.$colspan.'">';

						// Date planned
						print $langs->trans("DateStartPlanned").': ';
						if ($objp->date_start) {
							print dol_print_date($db->jdate($objp->date_start), 'day');
							// Warning si date prevu passee et pas en service
							if ($objp->status == 0 && $db->jdate($objp->date_start) < ($now - getDolGlobalInt('MAIN_DELAY_NOT_ACTIVATED_SUPPLIER_SERVICES')/*$conf->suppliercontract->services->inactifs->warning_delay*/)) {
								$warning_delay = getDolGlobalInt('MAIN_DELAY_NOT_ACTIVATED_SUPPLIER_SERVICES')/*$conf->suppliercontract->services->inactifs->warning_delay*/ / 3600 / 24;
								$textlate = $langs->trans("Late").' = '.$langs->trans("DateReference").' > '.$langs->trans("DateToday").' '.(ceil($warning_delay) >= 0 ? '+' : '').ceil($warning_delay).' '.$langs->trans("days");
								print " ".img_warning($textlate);
							}
						} else {
							print $langs->trans("Unknown");
						}
						print ' &nbsp;-&nbsp; ';
						print $langs->trans("DateEndPlanned").': ';
						if ($objp->date_end) {
							print dol_print_date($db->jdate($objp->date_end), 'day');
							if ($objp->status == 4 && $db->jdate($objp->date_end) < ($now - getDolGlobalInt('MAIN_DELAY_RUNNING_SUPPLIER_SERVICES')/*$conf->suppliercontract->services->expires->warning_delay*/)) {
								$warning_delay = getDolGlobalInt('MAIN_DELAY_RUNNING_SUPPLIER_SERVICES')/*$conf->suppliercontract->services->expires->warning_delay*/ / 3600 / 24;
								$textlate = $langs->trans("Late").' = '.$langs->trans("DateReference").' > '.$langs->trans("DateToday").' '.(ceil($warning_delay) >= 0 ? '+' : '').ceil($warning_delay).' '.$langs->trans("days");
								print " ".img_warning($textlate);
							}
						} else {
							print $langs->trans("Unknown");
						}

						print '</td>';
						print '</tr>';
					}

					// Display lines extrafields
					if (is_array($extralabelslines) && count($extralabelslines) > 0) {
						$line = new SupplierContractLine($db);
						$line->id = $objp->rowid;
						$line->fetch_optionals();
						print $line->showOptionals($extrafields, 'view', array('class' => 'oddeven', 'style' => $moreparam, 'colspan' => $colspan, 'tdclass' => 'notitlefieldcreate'), '', '', 1);
					}
				} else {
					$colspan = 7;

					// Line in mode update
					// Ligne carac
					print '<tr class="oddeven">';
					print '<td>';

					if ($objp->fk_product > 0) {
						$productstatic->id = $objp->fk_product;
						$productstatic->type = $objp->ptype;
						$productstatic->ref = $objp->pref;
						$productstatic->entity = $objp->pentity;
						$productstatic->label = $objp->plabel;
						$productstatic->status = $objp->tosell;
						$productstatic->status_buy = $objp->tobuy;
						$productstatic->status_batch = $objp->tobatch;

						$text = $productstatic->getNomUrl(1, '', 32);
						if ($objp->plabel) {
							$text .= ' - ';
							$text .= $objp->plabel;
						}
					} else {
						$text = img_object($langs->trans("ShowProductOrService"), ($objp->product_type ? 'service' : 'product')).' '.$objp->label_det;
					}
					print $text . '<br>';

					// editeur wysiwyg
					require_once DOL_DOCUMENT_ROOT.'/core/class/doleditor.class.php';
					$nbrows = ROWS_2;
					if (getDolGlobalString('MAIN_INPUT_DESC_HEIGHT')) {
						$nbrows = getDolGlobalString('MAIN_INPUT_DESC_HEIGHT');
					}
					$doleditor = new DolEditor('product_desc', (GETPOSTISSET('product_desc') ? GETPOST('product_desc') : $objp->description), '', 92, 'dolibarr_details', '', false, true, getDolGlobalInt('FCKEDITOR_ENABLE_DETAILS'), $nbrows, '90%');
					$doleditor->Create();

					print '</td>';

					// Ref supplier
					print '<td class="right linecolrefsupplier">';
					print '<input id="elfourn_ref" name="elfourn_ref" class="flat minwidth50 maxwidth100 maxwidth125onsmartphone" value="' . (GETPOSTISSET('elfourn_ref') ? GETPOST('elfourn_ref') : $objp->ref_supplier) . '">';
					print '</td>';

					// VAT
					print '<td class="right">';
					print $form->load_tva("eltva_tx", $objp->tva_tx.($objp->vat_src_code ? (' ('.$objp->vat_src_code.')') : ''), $mysoc, $object->thirdparty, $currentLineProductId, $objp->info_bits, $objp->product_type, 0, 1);
					print '</td>';

					// Price
					print '<td class="right"><input class="width50" type="text" name="elprice" value="'.(GETPOSTISSET('elprice') ? GETPOST('elprice') : price($objp->subprice)).'"></td>';

					// Price multicurrency
					/*if (isModEnabled("multicurrency")) {
					 print '<td class="linecoluht_currency nowrap right">'.price($objp->multicurrency_subprice).'</td>';
					 }*/

					// Quantity
					print '<td class="center"><input size="2" type="text" name="elqty" value="'.(GETPOSTISSET('elqty') ? GETPOST('elqty') : $objp->qty).'"></td>';

					// Unit
					if (getDolGlobalInt('PRODUCT_USE_UNITS')) {
						print '<td class="left">';
						print $form->selectUnits((GETPOSTISSET('unit') ? GETPOSTINT('unit') : $objp->fk_unit), "unit");
						print '</td>';
						$colspan++;
					}

					// Discount
					print '<td class="nowraponall right"><input size="1" type="text" name="elremise_percent" value="'.(GETPOSTISSET('elremise_percent') ? GETPOST('elremise_percent') : $objp->remise_percent).'">%</td>';

					print '<td class="center">';
					print '<input type="submit" class="button margintoponly marginbottomonly" name="save" value="'.$langs->trans("Modify").'">';
					print '<br><input type="submit" class="button margintoponly marginbottomonly button-cancel" name="cancel" value="'.$langs->trans("Cancel").'">';
					print '</td>';
					print '</tr>';

					// Line dates planned
					print '<tr class="oddeven">';
					print '<td colspan="'.$colspan.'">';
					print $langs->trans("DateStartPlanned").' ';
					print $form->selectDate($db->jdate($objp->date_start), "date_start_update", $usehm, $usehm, ($db->jdate($objp->date_start) > 0 ? 0 : 1), "update");
					print ' &nbsp;&nbsp;'.$langs->trans("DateEndPlanned").' ';
					print $form->selectDate($db->jdate($objp->date_end), "date_end_update", $usehm, $usehm, ($db->jdate($objp->date_end) > 0 ? 0 : 1), "update");
					print '</td>';
					print '</tr>';

					if (is_array($extralabelslines) && count($extralabelslines) > 0) {
						$line = new SupplierContractLine($db);
						$line->id = $objp->rowid;
						$line->fetch_optionals();

						print $line->showOptionals($extrafields, 'edit', array('style' => 'class="oddeven"', 'colspan' => $colspan, 'tdclass' => 'notitlefieldcreate'), '', '', 1);
					}
				}

				$db->free($result);
			} else {
				dol_print_error($db);
			}

			if ($object->status > 0) {
				$moreparam = '';
				if (getDolGlobalString('SUPPLIERCONTRACT_HIDE_CLOSED_SERVICES_BY_DEFAULT') && $object->lines[$cursorline - 1]->status == SupplierContractLine::STATUS_CLOSED && $action != 'showclosedlines') {
					$moreparam = 'style="display: none;"';
				}

				$colspan = 6;
				if (getDolGlobalInt('PRODUCT_USE_UNITS')) {
					$colspan++;
				}

				print '<tr class="oddeven" '.$moreparam.'>';
				print '<td class="tdhrthin" colspan="'.$colspan.'"><hr class="opacitymedium tdhrthin"></td>';
				print "</tr>\n";
			}

			print "</table>";
			print '</div>';

			print "</form>\n";


			/*
			 * Confirmation to delete service line of supplier contract
			 */
			if ($action == 'deleteline' && !$cancel && $user->hasRight('suppliercontract', 'creer') && $object->lines[$cursorline - 1]->id == $idline) {
				print $form->formconfirm($_SERVER["PHP_SELF"]."?id=".((int) $object->id)."&lineid=".((int) $idline), $langs->trans("DeleteSupplierContractLine"), $langs->trans("ConfirmDeleteSupplierContractLine"), "confirm_deleteline", '', 0, 1);
				if ($ret == 'html') {
					print '<table class="notopnoleftnoright centpercent"><tr class="oddeven" height="6"><td></td></tr></table>';
				}
			}

			/*
			 * Confirmation to move service toward another supplier contract
			 */
			if ($action == 'move' && !$cancel && $user->hasRight('suppliercontract', 'creer') && $object->lines[$cursorline - 1]->id == $idline) {
				$arraysuppliercontractid = array();
				foreach ($arrayothersuppliercontracts as $contractcursor) {
					$arraysuppliercontractid[$contractcursor->id] = $contractcursor->ref;
				}
				//var_dump($arraysuppliercontractid);
				// Cree un tableau formulaire
				$formquestion = array(
				'text' => $langs->trans("ConfirmMoveToAnotherSupplierContractQuestion"),
				0 => array('type' => 'select', 'name' => 'newcid', 'values' => $arraysuppliercontractid));

				print $form->formconfirm($_SERVER["PHP_SELF"]."?id=".((int) $object->id)."&lineid=".((int) $idline), $langs->trans("MoveToAnotherSupplierContract"), $langs->trans("ConfirmMoveToAnotherSupplierContract"), "confirm_move", $formquestion, 'yes');
				print '<table class="notopnoleftnoright centpercent"><tr class="oddeven" height="6"><td></td></tr></table>';
			}

			// Area with status and activation info of line
			if ($object->status > 0) {
				print '<table class="notopnoleftnoright tableforservicepart2'.($cursorline < $nbofservices ? ' boxtablenobottom' : '').' centpercent">';

				print '<tr class="oddeven" '.$moreparam.'>';
				print '<td><span class="valignmiddle hideonsmartphone">'.$langs->trans("ServiceStatus").':</span> '.$object->lines[$cursorline - 1]->getLibStatut(4).'</td>';
				print '<td width="30" class="right">';
				if ($user->socid == 0) {
					if ($object->status > 0 && $action != 'activateline' && $action != 'unactivateline' && is_object($objp)) {
						$tmpaction = 'activateline';
						$tmpactionpicto = 'play';
						$tmpactiontext = $langs->trans("Activate");
						if ($objp->status == 4) {
							$tmpaction = 'unactivateline';
							$tmpactionpicto = 'playstop';
							$tmpactiontext = $langs->trans("Disable");
						}
						if (($tmpaction == 'activateline' && $user->hasRight('suppliercontract', 'activer')) || ($tmpaction == 'unactivateline' && $user->hasRight('suppliercontract', 'desactiver'))) {
							print '<a class="reposition" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&amp;ligne='.$object->lines[$cursorline - 1]->id.'&amp;action='.$tmpaction.'&token='.newToken().'">';
							print img_picto($tmpactiontext, $tmpactionpicto);
							print '</a>';
						}
					}
				}
				print '</td>';
				print "</tr>\n";

				print '<tr class="oddeven" '.$moreparam.'>';

				print '<td>';
				// Si pas encore active
				if (!$objp->date_start_real) {
					print $langs->trans("DateStartReal").': ';
					if ($objp->date_start_real) {
						print dol_print_date($db->jdate($objp->date_start_real), 'day');
					} else {
						print $langs->trans("SupplierContractStatusNotRunning");
					}
				}
				// Si active et en cours
				if ($objp->date_start_real && !$objp->date_end_real) {
					print $langs->trans("DateStartReal").': ';
					print dol_print_date($db->jdate($objp->date_start_real), 'day');
				}
				// Si desactive
				if ($objp->date_start_real && $objp->date_end_real) {
					print $langs->trans("DateStartReal").': ';
					print dol_print_date($db->jdate($objp->date_start_real), 'day');
					print ' &nbsp;-&nbsp; ';
					print $langs->trans("DateEndReal").': ';
					print dol_print_date($db->jdate($objp->date_end_real), 'day');
				}
				if (!empty($objp->comment)) {
					print " &nbsp;-&nbsp; ".$objp->comment;
				}
				print '</td>';

				print '<td class="center">&nbsp;</td>';

				print '</tr>';
				print '</table>';
			}

			// Form to activate line
			if ($user->hasRight('suppliercontract', 'activer') && $action == 'activateline' && $object->lines[$cursorline - 1]->id == GETPOSTINT('ligne') && is_object($objp)) {
				print '<form name="active" action="'.$_SERVER["PHP_SELF"].'" method="POST">';
				print '<input type="hidden" name="token" value="'.newToken().'">';
				print '<input type="hidden" name="action" value="confirm_active">';
				print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';
				print '<input type="hidden" name="id" value="'.$object->id.'">';
				print '<input type="hidden" name="ligne" value="'.GETPOSTINT('ligne').'">';
				print '<input type="hidden" name="confirm" value="yes">';

				print '<table class="noborder tableforservicepart2'.($cursorline < $nbofservices ? ' boxtablenobottom' : '').' centpercent">';

				// Definie date debut et fin par default
				$dateactstart = $objp->date_start;
				if (GETPOST('remonth')) {
					$dateactstart = dol_mktime(12, 0, 0, GETPOST('remonth'), GETPOST('reday'), GETPOST('reyear'));
				} elseif (!$dateactstart) {
					$dateactstart = time();
				}

				$dateactend = $objp->date_end;
				if (GETPOST('endmonth')) {
					$dateactend = dol_mktime(12, 0, 0, GETPOST('endmonth'), GETPOST('endday'), GETPOST('endyear'));
				} elseif (!$dateactend) {
					if ($objp->fk_product > 0) {
						$product = new Product($db);
						$product->fetch($objp->fk_product);
						$dateactend = dol_time_plus_duree(time(), $product->duration_value, $product->duration_unit);
					}
				}

				print '<tr class="oddeven">';
				print '<td class="nohover">'.$langs->trans("DateServiceActivate").'</td><td class="nohover">';
				print $form->selectDate($dateactstart, 'start', $usehm, $usehm, 0, "active", 1, 0);
				print '</td>';
				print '<td class="nohover">'.$langs->trans("DateEndPlanned").'</td><td class="nohover">';
				print $form->selectDate($dateactend, "end", $usehm, $usehm, 0, "active", 1, 0);
				print '</td>';
				print '<td class="center nohover">';
				print '</td>';

				print '</tr>';

				print '<tr class="oddeven">';
				print '<td class="nohover">'.$langs->trans("Comment").'</td><td colspan="3" class="nohover"><input type="text" class="minwidth300" name="comment" value="'.dol_escape_htmltag(GETPOST("comment", 'alphanohtml')).'"></td>';
				print '<td class="nohover right">';
				print '<input type="submit" class="button" name="activate" value="'.$langs->trans("Activate").'"> &nbsp; ';
				print '<input type="submit" class="button button-cancel" name="cancel" value="'.$langs->trans("Cancel").'">';
				print '</td>';
				print '</tr>';

				print '</table>';

				print '</form>';
			}

			if ($user->hasRight('suppliercontract', 'activer') && $action == 'unactivateline' && $object->lines[$cursorline - 1]->id == GETPOSTINT('ligne') && is_object($objp)) {
				/**
				 * Disable a supplier contract line
				 */
				print '<!-- Form to disabled a line -->'."\n";
				print '<form name="confirm_closeline" action="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&amp;ligne='.$object->lines[$cursorline - 1]->id.'" method="post">';
				print '<input type="hidden" name="token" value="'.newToken().'">';
				print '<input type="hidden" name="confirm" value="yes">';
				print '<input type="hidden" name="action" value="confirm_closeline">';
				print '<input type="hidden" name="backtopage" value="'.$backtopage.'">';

				print '<table class="noborder tableforservicepart2'.($cursorline < $nbofservices ? ' boxtablenobottom' : '').' centpercent">';

				// Definie date debut et fin par default
				$dateactstart = $objp->date_start_real;
				if (GETPOST('remonth')) {
					$dateactstart = dol_mktime(12, 0, 0, GETPOST('remonth'), GETPOST('reday'), GETPOST('reyear'));
				} elseif (!$dateactstart) {
					$dateactstart = time();
				}

				$dateactend = $objp->date_end_real;
				if (GETPOST('endmonth')) {
					$dateactend = dol_mktime(12, 0, 0, GETPOST('endmonth'), GETPOST('endday'), GETPOST('endyear'));
				} elseif (!$dateactend) {
					if ($objp->fk_product > 0) {
						$product = new Product($db);
						$product->fetch($objp->fk_product);
						$dateactend = dol_time_plus_duree(time(), $product->duration_value, $product->duration_unit);
					}
				}
				$now = dol_now();
				if ($dateactend > $now) {
					$dateactend = $now;
				}

				print '<tr class="oddeven"><td colspan="2" class="nohover">';
				if ($objp->status >= 4) {
					if ($objp->status == 4) {
						print $langs->trans("DateEndReal").' ';
						print $form->selectDate($dateactend, "end", $usehm, $usehm, ($objp->date_end_real > 0 ? 0 : 1), "closeline", 1, 1);
					}
				}
				print '</td>';
				print '<td class="center nohover">';
				print '</td></tr>';

				print '<tr class="oddeven">';
				print '<td class="nohover">'.$langs->trans("Comment").'</td><td class="nohover"><input class="quatrevingtpercent" type="text" class="flat" name="comment" value="'.dol_escape_htmltag(GETPOST('comment', 'alpha')).'"></td>';
				print '<td class="nohover right">';
				print '<input type="submit" class="button" name="close" value="'.$langs->trans("Disable").'"> &nbsp; ';
				print '<input type="submit" class="button button-cancel" name="cancel" value="'.$langs->trans("Cancel").'">';
				print '</td>';
				print '</tr>';

				print '</table>';

				print '</form>';
			}
			print '</div>';
			$cursorline++;
		}
		print '</div>';

		// Form to add new line
		if ($user->hasRight('suppliercontract', 'creer') && ($object->status == 0)) {
			// Add free products/services form

			print "\n";
			print '	<form name="addproduct" id="addproduct" action="'.$_SERVER["PHP_SELF"].'?id='.$object->id.(($action != 'editline') ? '' : '#line_'.GETPOSTINT('lineid')).'" method="POST">
			<input type="hidden" name="token" value="'.newToken().'">
			<input type="hidden" name="action" value="'.(($action != 'editline') ? 'addline' : 'updateline').'">
			<input type="hidden" name="mode" value="">
			<input type="hidden" name="id" value="'.$object->id.'">
			<input type="hidden" name="page_y" value="">
			<input type="hidden" name="backtopage" value="'.$backtopage.'">
			';

			print '<div class="div-table-responsive-no-min">';
			print '<table id="tablelines" class="noborder noshadow" width="100%">'; // Array with (n*2)+1 lines

			// Form to add new line
			if ($action != 'editline') {
				$forcetoshowtitlelines = 1;
				if (empty($object->multicurrency_code)) {
					$object->multicurrency_code = $conf->currency; // TODO Remove this when multicurrency supported on supplier contracts
				}

				// Add free products/services

				$parameters = array();
				$reshook = $hookmanager->executeHooks('formAddObjectLine', $parameters, $object, $action); // Note that $action and $object may have been modified by hook
				if ($reshook < 0) {
					setEventMessages($hookmanager->error, $hookmanager->errors, 'errors');
				}
				if (empty($reshook)) {
					$object->formAddObjectLine(1, $soc, $mysoc);
				}
			}

			print '</table>';
			print '</div>';
			print '</form>';
		}

		print dol_get_fiche_end();

		// Select mail models is same action as presend
		if (GETPOST('modelselected')) {
			$action = 'presend';
		}

		/*
		 * Buttons
		 */
		if ($user->socid == 0 && $action != 'presend' && $action != 'editline') {
			print '<div class="tabsAction">';

			$parameters = array();
			$reshook = $hookmanager->executeHooks('addMoreActionsButtons', $parameters, $object, $action); // Note that $action and $object may have been modified by hook

			if (empty($reshook)) {
				$params = array(
					'attr' => array(
						'title' => '',
						'class' => 'classfortooltip'
					)
				);

				// Send
				if (empty($user->socid)) {
					if ($object->status == $object::STATUS_VALIDATED) {
						if ((!getDolGlobalString('MAIN_USE_ADVANCED_PERMS') || $user->hasRight('suppliercontract', 'creer'))) {
							print dolGetButtonAction('', $langs->trans('SendMail'), 'default', $_SERVER["PHP_SELF"].'?id='.$object->id.'&action=presend&token='.newToken().'&mode=init#formmailbeforetitle', '', true, $params);
						} else {
							print dolGetButtonAction('', $langs->trans('SendMail'), 'default', '#', '', false, $params);
						}
					}
				}

				if ($object->status == $object::STATUS_DRAFT && $nbofservices) {
					if ($user->hasRight('suppliercontract', 'creer')) {
						unset($params['attr']['title']);
						print dolGetButtonAction($langs->trans('Validate'), '', 'default', $_SERVER["PHP_SELF"].'?id='.$object->id.'&action=valid&token='.newToken(), '', true, $params);
					} else {
						$params['attr']['title'] = $langs->trans("NotEnoughPermissions");
						print dolGetButtonAction($langs->trans('Validate'), '', 'default', '#', '', false, $params);
					}
				}
				if ($object->status == $object::STATUS_VALIDATED) {
					if ($user->hasRight('suppliercontract', 'creer')) {
						unset($params['attr']['title']);
						print dolGetButtonAction($langs->trans('Modify'), '', 'default', $_SERVER["PHP_SELF"].'?id='.$object->id.'&action=reopen&token='.newToken(), '', true, $params);
					} else {
						$params['attr']['title'] = $langs->trans("NotEnoughPermissions");
						print dolGetButtonAction($langs->trans('Modify'), '', 'default', '#', '', false, $params);
					}
				}

				// Create ... buttons
				$arrayofcreatebutton = array();
				if (isModEnabled('supplier_proposal') && $object->status > 0 && $object->nbofservicesclosed < $nbofservices) {
					$arrayofcreatebutton[] = array(
						'url' => '/supplier_proposal/card.php?action=create&token='.newToken().'&origin='.$object->element.'&originid='.$object->id.'&socid='.$object->thirdparty->id,
						'label' => $langs->trans('AddSupplierProposal'),
						'lang' => 'supplier_proposal',
						'perm' => $user->hasRight('supplier_proposal', 'creer'),
						'enabled' => true,
					);
				}
				if (isModEnabled('order') && $object->status > 0 && $object->nbofservicesclosed < $nbofservices) {
					$arrayofcreatebutton[] = array(
						'url' => '/fourn/commande/card.php?action=create&token='.newToken().'&origin='.$object->element.'&originid='.$object->id.'&socid='.$object->thirdparty->id,
						'label' => $langs->trans('AddSupplierOrder'),
						'lang' => 'orders',
						'perm' => $user->hasRight('fournisseur', 'commande', 'creer'),
						'enabled' => true,
					);
				}
				if (isModEnabled('supplier_invoice') && $object->status > 0) {
					$langs->load("suppliers");
					$arrayofcreatebutton[] = array(
						'url' => '/fourn/facture/card.php?action=create&origin='.$object->element.'&originid='.$object->id.'&socid='.$object->thirdparty->id,
						'label' => $langs->trans('AddSupplierInvoice'),
						'lang' => 'bills',
						'perm' => $user->hasRight('fournisseur', 'facture', 'creer'),
						'enabled' => true,
					);
				}
				if (count($arrayofcreatebutton)) {
					unset($params['attr']['title']);
					print dolGetButtonAction('', $langs->trans("Create"), 'default', $arrayofcreatebutton, '', true, $params);
				}

				$arrayforbutaction = array();
				if ($object->nbofservicesclosed > 0 || $object->nbofserviceswait > 0) {
					$arrayforbutaction[] = array(
						'url' => '/custom/suppliercontract/card.php?id='.$object->id.'&action=activate&token='.newToken(), // dont use dol_buildpath in function but DOL_URL_ROOT
						'label' => $langs->trans('ActivateAllSupplierContracts'),
						'lang' => 'bills',
						'perm' => $user->hasRight('suppliercontract', 'activer'),
						'enabled' => true,
					);
				}
				if ($object->nbofservicesclosed < $nbofservices) {
					$arrayforbutaction[] = array(
						'url' => '/custom/suppliercontract/card.php?id='.$object->id.'&action=close&token='.newToken(), // dont use dol_buildpath in function but DOL_URL_ROOT
						'label' => $langs->trans('CloseAllSupplierContracts'),
						'lang' => 'bills',
						'perm' => $user->hasRight('suppliercontract', 'desactiver'),
						'enabled' => true,
					);
				}

				if (count($arrayforbutaction)) {
					unset($params['attr']['title']);
					print dolGetButtonAction($langs->trans("Services"), $langs->trans("Services"), 'default', $arrayforbutaction, '', true, $params);
				}

				if (getDolGlobalString('SUPPLIERCONTRACT_HIDE_CLOSED_SERVICES_BY_DEFAULT') && $object->nbofservicesclosed > 0) {
					if ($action == 'showclosedlines') {
						print '<div class="inline-block divButAction"><a class="butAction" id="btnhideclosedlines" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&amp;action=hideclosedlines">'.$langs->trans("HideClosedServices").'</a></div>';
					} else {
						print '<div class="inline-block divButAction"><a class="butAction" id="btnshowclosedlines" href="'.$_SERVER["PHP_SELF"].'?id='.$object->id.'&amp;action=showclosedlines">'.$langs->trans("ShowClosedServices").'</a></div>';
					}
				}

				// Sign
				if ($object->status > SupplierContract::STATUS_DRAFT) {
					if ($object->signed_status != SupplierContract::$SIGNED_STATUSES['STATUS_SIGNED_ALL']) {
						print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '&action=sign&token=' . newToken() . '">' . $langs->trans("SupplierContractSign") . '</a></div>';
					} else {
						print '<div class="inline-block divButAction"><a class="butAction" href="' . $_SERVER["PHP_SELF"] . '?id=' . $object->id . '&action=unsign&token=' . newToken() . '">' . $langs->trans("SupplierContractUnsign") . '</a></div>';
					}
				}

				// Clone
				if ($user->hasRight('suppliercontract', 'creer')) {
					unset($params['attr']['title']);
					print dolGetButtonAction($langs->trans('ToClone'), '', 'default', $_SERVER['PHP_SELF'].'?id='.$object->id.'&socid='.$object->socid.'&action=clone&token='.newToken(), '', true, $params);
				}

				// Delete
				unset($params['attr']['title']);
				print dolGetButtonAction($langs->trans('Delete'), '', 'delete', $_SERVER["PHP_SELF"].'?id='.$object->id.'&action=delete&token='.newToken(), '', $permissiontodelete, $params);
			}

			print "</div>";
		}

		if ($action != 'presend') {
			print '<div class="fichecenter"><div class="fichehalfleft">';

			/*
			 * Generated documents
			 */
			$filename = dol_sanitizeFileName($object->ref);
			$filedir = $conf->suppliercontract->multidir_output[$object->entity]."/".dol_sanitizeFileName($object->ref);
			$urlsource = $_SERVER["PHP_SELF"]."?id=".$object->id;
			$genallowed = $user->hasRight('suppliercontract', 'lire');
			$delallowed = $user->hasRight('suppliercontract', 'creer');


			print $formfile->showdocuments('suppliercontract', $filename, $filedir, $urlsource, $genallowed, $delallowed, ($object->model_pdf ? $object->model_pdf : getDolGlobalString('SUPPLIERCONTRACT_ADDON_PDF')), 1, 0, 0, 28, 0, '', 0, '', $soc->default_lang, '', $object);


			// Show links to link elements
			$linktoelem = $form->showLinkToObjectBlock($object, array(), array('suppliercontract'));
			$somethingshown = $form->showLinkedObjectBlock($object, $linktoelem);

			print '</div><div class="fichehalfright">';

			$MAXEVENT = 10;

			$morehtmlcenter = '<div class="nowraponall">';
			//$morehtmlcenter .= dolGetButtonTitle($langs->trans('FullConversation'), '', 'fa fa-comments imgforviewmode', dol_buildpath('/suppliercontract/messaging.php',1).'?id='.$object->id);
			$morehtmlcenter .= dolGetButtonTitle($langs->trans('SeeAll'), '', 'fa fa-bars imgforviewmode', dol_buildpath('/suppliercontract/agenda.php',1).'?id='.$object->id);
			$morehtmlcenter .= '</div>';


			// List of actions on element
			include_once DOL_DOCUMENT_ROOT.'/core/class/html.formactions.class.php';
			$formactions = new FormActions($db);
			$somethingshown = $formactions->showactions($object, 'suppliercontract', $socid, 1, 'listactions', $MAXEVENT, '', $morehtmlcenter);

			print '</div></div>';
		}

		// Presend form
		$modelmail = 'suppliercontract';
		$defaulttopic = 'SendSupplierContractRef';
		$diroutput = $conf->suppliercontract->multidir_output[$object->entity];
		$trackid = 'scn'.$object->id;

		include DOL_DOCUMENT_ROOT.'/core/tpl/card_presend.tpl.php';
	}
}


llxFooter();

$db->close();
